#delimit ;

*
* ADATA.DO  -- creates ADATA2.DTA, dataset for 
*              state-year-age regressions that includes
*              updated arrests data, DL's new abortion 
*              data, etc.
* ;

set mem 1g;
set matsize 8000;

/* ******************************************************************** */
/* Get data from DLAB_FG06                                            * */ 

use dlab_fg06;
sort fips year;
keep fips year proarr*    vioarr* 
               newproarr* newvioarr* 
               abort abresrt region division;

reshape long proarr vioarr newproarr newvioarr, j(age) i(fips year);

rename proarr fg06proarr;
rename vioarr fg06vioarr;
sort fips year age;

desc;
summ;
summ if year >= 85 & year <= 98;
summ if year == 97;
summ if year == 98;

sort fips year age;
save temp, replace;
clear;

/* ******************************************************************* */
/* Get data from DL (2006)'s REGREADY                                  */

use ../DLdata/regready;
keep fips year age popul yobstate
                   violarr proparr 
                   hist_abt_orig_no 
                   hist_abt_cdcocc 
                   hist_abt;

rename proparr rrproparr;
rename violarr rrviolarr;

sort fips year age;
desc;
summ;

merge fips year age using temp;
tab _merge;
drop _merge;
erase temp.dta;

desc;
summ;

* Do some checks; 

* These _CK variables should all be 
* zeros, b/c we do not update the 
* arrest data on DLAB_FG06 (we do
* this below, only write NEWARR vars). 
* DLAB_FG06's PROARR and VIOARR come 
* directly from the original DLAB 2.1.DTA;

gen pro_ck = fg06proarr - rrproparr;
gen vio_ck = fg06vioarr - rrviolarr;

summ fips year fg06* rr* *ck;
summ fips year fg06* rr* *ck if year >= 85 & year <= 98;
drop pro_ck vio_ck;

* There will be some differences
* between our updated arrests and the data on the 
* REGREADY file. Any differences should only be 
* for the years in which these data overlap (97 
* & 98). Turns out only 98 is different, but 
* only barely. DLAB_FG06 already deleted MN data for 97;
* which was way off;

preserve ;

keep if year == 97 | year == 98;

list fips year rrproparr newproarr if rrproparr == . & newproarr ~= . & year == 97;
list fips year rrproparr newproarr if rrproparr ~= . & newproarr == . & year == 97;
list fips year rrproparr newproarr if rrproparr == . & newproarr ~= . & year == 98;
list fips year rrproparr newproarr if rrproparr ~= . & newproarr == . & year == 98;

list fips year rrviolarr newvioarr if rrviolarr == . & newvioarr ~= . & year == 97;
list fips year rrviolarr newvioarr if rrviolarr ~= . & newvioarr == . & year == 97;
list fips year rrviolarr newvioarr if rrviolarr == . & newvioarr ~= . & year == 98;
list fips year rrviolarr newvioarr if rrviolarr ~= . & newvioarr == . & year == 98;

gen newpro_ck = 100*(newproarr - rrproparr)/rrproparr;
gen newvio_ck = 100*(newvioarr - rrviolarr)/rrviolarr;

list fips year rrproparr newproarr newpro_ck if newpro_ck ~= .  & newpro_ck ~= 0;
list fips year rrviolarr newvioarr newvio_ck if newvio_ck ~= .  & newvio_ck ~= 0;

drop newpro_ck newvio_ck;

restore;

/* ********************************************************** */
* Now create the abortion variables used in the state-year-age
* regressions. 
*
* The '10's in the formulas below comes from the fact that 
* each year has 10 ages, so we have to jump back over
* 10 observations to get the relevant abortion rate for 
* every year we go back;

sort fips year age;
by fips: gen hist_abt_orig_ck =   abort[_n-((age+1)*10)]/100;
by fips: gen ha_res           = abresrt[_n-((age+1)*10)]/100;

by fips: gen ha_restime      =  (18/144)*abresrt[_n-((age+2)*10)]/100 + 
                               (108/144)*abresrt[_n-((age+1)*10)]/100 + 
                                (18/144)*abresrt[_n-((age)*10)]/100;

* ABORT_CK should all be 0 if our new way 
* of creating the abortion exposure variable 
* is equivalent to DL's way;
gen abort_ck = hist_abt_orig_no - hist_abt_orig_ck;
summ hist_abt_orig_no hist_abt_orig_ck abort_ck;
summ hist_abt_orig_no hist_abt_orig_ck abort_ck if hist_abt_orig_no ~= .;
drop abort_ck;

/* ********************************************************* */
* Write the updated arrests data;
*
* Use the 1985-98 arrests for violent crime and property 
* crime from REGREADY;

gen proparr = rrproparr;
gen violarr = rrviolarr;

* Update the age-specific arrests data, but ONLY
* for years *after* 1998. There are a few minor differences 
* between our 1998 NEWarrests data and the 1998 data on DLAB 2.1,
* (see above) but we'll keep theirs; 

replace proparr = newproarr if newproarr ~= . & year > 98;
replace violarr = newvioarr if newvioarr ~= . & year > 98;

replace year = year + 1900;
sort fips year age;

/* ************************************************************ */
/* Merge in the state-year-age population data from COMBINED    */

merge fips year age using popdata/combined;
tab _merge;
drop _merge;

* SEERPOP is not available in 2003, so REPLACE it 
* with the Census data (which is close to SEERPOP 
* after the 2000 Census);
replace seerpop = censuspop if year >= 2003;

/* *********************************************************** */
/* Keep only the required years and ages, then save            */

keep if year >= 1985 & year <= 2003;
keep if age  >= 15 & age <= 24;

desc;
summ;

sort fips year age;
list fips year age censuspop seerpop popul if fips == 1;

save adata, replace;
clear;

exit, clear;

