*
* newarrests.do --- age-specific arrest totals 
*                   from 1997 through 2003. Note that 
*                   two states (DC & WI) look like
*                   the data are poor. KS also 
*                   looks suspicious, but less problematic. Also, 
*                   in comparisons with the 1997 arrest 
*                   data in DLAB 2.1.DTA, it looks like 
*                   MN's data for 1997 are not recorded 
*                   well. 
* ;
#delimit;


clear;
set more off;
set mem 1g;

************************************************************* ;
************************************************************* ;
*** Loop through years                                     ** ;
************************************************************* ;
************************************************************* ;

local years 97 98 99 00 01 02 03 ; 
foreach y of local years { ;
	use ../../../arrestdata/statadata/in`y'.dta, clear ;

*** keep relevant variables ;

keep state      off m0* m1* m2* m3* m4* m5* m6* 
                    f0* f1* f2* f3* f4* f5* f6*;

*** get a listing of offense codes ;
tab off;
keep if off == "01A" | off == "02"  | off == "03"  | off == "04" 
      | off == "05"  | off == "06"  | off == "07"  | off == "08"
      | off == "011" | off == "020" | off == "030" | off == "040" 
      | off == "050" | off == "060" | off == "070" | off == "080";

tab off;

*** replace all the 'none/not reported' with zeros and add across genders ; 

local listnums 0_9 10_12 13_14 
               15 16 17 18 19 20 21 22 23 24 
               25_29 30_34 35_39 40_44 45_49 50_54 55_59 60_64 65;

foreach x of local listnums {;
  replace m`x' = 0 if m`x' == .;
  replace f`x' = 0 if f`x' == .;
  gen a`x' = m`x' + f`x';
};

keep state off a0* a1* a2* a3* a4* a5* a6*;
summ;

*** collapse by state and offense;

sort state off;
collapse (sum) a0* a1* a2* a3* a4* a5* a6*, by(state off);

tab state;
summ;

foreach x of local listnums {;
  gen murd`x' = a`x' if ((off == "01A" & `y' ~= 02) | (off == "011" & `y' == 02));
  gen rape`x' = a`x' if ((off == "02"  & `y' ~= 02) | (off == "020" & `y' == 02));
  gen robb`x' = a`x' if ((off == "03"  & `y' ~= 02) | (off == "030" & `y' == 02));
  gen assa`x' = a`x' if ((off == "04"  & `y' ~= 02) | (off == "040" & `y' == 02));
  gen burg`x' = a`x' if ((off == "05"  & `y' ~= 02) | (off == "050" & `y' == 02));
  gen larc`x' = a`x' if ((off == "06"  & `y' ~= 02) | (off == "060" & `y' == 02));
  gen moto`x' = a`x' if ((off == "07"  & `y' ~= 02) | (off == "070" & `y' == 02));
  gen arsn`x' = a`x' if ((off == "09"  & `y' ~= 02) | (off == "090" & `y' == 02));
  replace murd`x' = 0 if murd`x' == .;
  replace rape`x' = 0 if rape`x' == .;
  replace robb`x' = 0 if robb`x' == .;
  replace assa`x' = 0 if assa`x' == .;
  replace burg`x' = 0 if burg`x' == .;
  replace larc`x' = 0 if larc`x' == .;
  replace moto`x' = 0 if moto`x' == .;
  replace arsn`x' = 0 if arsn`x' == .;
};

collapse (sum) murd* rape* robb* assa* burg* larc* moto* arsn*, by(state);

*** add up the violent and property indexes by age ;
*** and write the murder variable as well          ;

foreach x of local listnums {;
  gen proarr`x' = burg`x' + larc`x' + moto`x' + arsn`x';
  gen vioarr`x' = murd`x' + rape`x' + robb`x' + assa`x';
  gen murarr`x' = murd`x';
};

gen year = `y';

keep state year vioarr* proarr* murarr*;

save new_`y'.dta, replace;
};

******************************************************** ;
******************************************************** ;
*** Put all the years together                        ** ;
******************************************************** ;
******************************************************** ;

use          new_97.dta, clear;
append using new_98.dta;
append using new_99.dta;
append using new_00.dta;
append using new_01.dta;
append using new_02.dta;
append using new_03.dta; 

sort state year;
save newarrests_0.dta, replace;

******************************************************* ;
******************************************************* ;
** Write FIPS and clean up YEAR variables, and save *** ;
******************************************************* ;
******************************************************* ;

use newarrests_0.dta, clear;

sort state year;
rename state icpsrstate;

tab icpsrstate;

gen fips = 999;                                                      
                                                                     
replace fips = 01 if icpsrstate ==   1; *    AL; 
replace fips = 04 if icpsrstate ==   2; *    AZ; 
replace fips = 05 if icpsrstate ==   3; *    AR; 
replace fips = 06 if icpsrstate ==   4; *    CA; 
replace fips = 08 if icpsrstate ==   5; *    CO; 
replace fips = 09 if icpsrstate ==   6; *    CT; 
replace fips = 10 if icpsrstate ==   7; *    DE; 
replace fips = 11 if icpsrstate ==   8; *    DC; 
replace fips = 12 if icpsrstate ==   9; *    FL; 
replace fips = 13 if icpsrstate ==  10; *    GA; 
replace fips = 16 if icpsrstate ==  11; *    ID;
replace fips = 17 if icpsrstate ==  12; *    IL; 
replace fips = 18 if icpsrstate ==  13; *    IN; 
replace fips = 19 if icpsrstate ==  14; *    IA; 
replace fips = 20 if icpsrstate ==  15; *    KS; 
replace fips = 21 if icpsrstate ==  16; *    KY; 
replace fips = 22 if icpsrstate ==  17; *    LA; 
replace fips = 23 if icpsrstate ==  18; *    ME; 
replace fips = 24 if icpsrstate ==  19; *    MD; 
replace fips = 25 if icpsrstate ==  20; *    MA; 
replace fips = 26 if icpsrstate ==  21; *    MI; 
replace fips = 27 if icpsrstate ==  22; *    MN; 
replace fips = 28 if icpsrstate ==  23; *    MS; 
replace fips = 29 if icpsrstate ==  24; *    MO; 
replace fips = 30 if icpsrstate ==  25; *    MT; 
replace fips = 31 if icpsrstate ==  26; *    NE; 
replace fips = 32 if icpsrstate ==  27; *    NV; 
replace fips = 33 if icpsrstate ==  28; *    NH; 
replace fips = 34 if icpsrstate ==  29; *    NJ; 
replace fips = 35 if icpsrstate ==  30; *    NM; 
replace fips = 36 if icpsrstate ==  31; *    NY; 
replace fips = 37 if icpsrstate ==  32; *    NC; 
replace fips = 38 if icpsrstate ==  33; *    ND; 
replace fips = 39 if icpsrstate ==  34; *    OH; 
replace fips = 40 if icpsrstate ==  35; *    OK; 
replace fips = 41 if icpsrstate ==  36; *    OR; 
replace fips = 42 if icpsrstate ==  37; *    PA; 
replace fips = 44 if icpsrstate ==  38; *    RI; 
replace fips = 45 if icpsrstate ==  39; *    SC; 
replace fips = 46 if icpsrstate ==  40; *    SD; 
replace fips = 47 if icpsrstate ==  41; *    TN; 
replace fips = 48 if icpsrstate ==  42; *    TX; 
replace fips = 49 if icpsrstate ==  43; *    UT; 
replace fips = 50 if icpsrstate ==  44; *    VT; 
replace fips = 51 if icpsrstate ==  45; *    VA; 
replace fips = 53 if icpsrstate ==  46; *    WA; 
replace fips = 54 if icpsrstate ==  47; *    WV; 
replace fips = 55 if icpsrstate ==  48; *    WI; 
replace fips = 56 if icpsrstate ==  49; *    WY; 
replace fips = 02 if icpsrstate ==  50; *    AK; 
replace fips = 15 if icpsrstate ==  51; *    HI;

tab fips;
tab icpsrstate if fips == 999;
drop icpsrstate;
drop if fips == 999;
tab fips; 

tab year;
replace year = 100 if year == 0;
replace year = 101 if year == 1;
replace year = 102 if year == 2;
replace year = 103 if year == 3;
tab year;

/* Write ages for individual years in WIDE form ****** */

sort fips year;
preserve; 

keep fips year proarr15-proarr24 vioarr15-vioarr24 murarr15-murarr24;
foreach x of numlist 15/24 {;
  rename proarr`x' newproarr`x';
  rename vioarr`x' newvioarr`x';
  rename murarr`x' newmurarr`x';
};

keep fips year newproarr*
               newvioarr*
               newmurarr*;

sort fips year;
tsset fips year;
save newarrests_wide, replace;

/* Write ages for individual years in LONG form ****** */

sort fips year;
tsset fips year;

reshape long newproarr newvioarr newmurarr, j(age) i(fips year);
sort fips year age;
save newarrests_long, replace;

/* Clean up *************************************** */

erase new_97.dta;
erase new_98.dta;
erase new_99.dta;
erase new_00.dta;
erase new_01.dta;
erase new_02.dta;
erase new_03.dta; 
erase newarrests_0.dta;

exit, clear;
