/* **************************************   
 DLAB_FG06.DO -- Foote/Goetz 2006 addn's to 
     DLAB 2.1.DTA                         
                                           
  1. Expands yearly state-level per-capita  
     crime rates to 2003 and back to 1960.  
     NY data is available only staring in 1965.
     Also makes add'l (small) change of     
     using updated Census data for population 
     for per capita rates. These 'new' per-capita
     crime rates are essentially identical 
     to the old per capita rates during the period
     of overlap, suggesting that using the 
     Census data for population doesn't make 
     much difference (POPUL looks slightly different
     from CENSPOP only in the 1990s). The only perplexing 
     difference b/t our per-capita crime rates and those 
     in DLAB 2.1 is in the late 70s/early 80s for 
     Illinois property and violent crimes. 
                                            
  2. Writes new 'effective abortion rates'
     (NEWEFA variables) to reflect resident 
     abortions (ABRESRT) rather than original 
     DL 2001 measure (ABORT). We extend these 
     to 2003, so we have to add in the weights 
     for persons in their early 30s to be accurate 
     for the 5 early-legalizing states.

  3. Re-writes Census REGION and DIVISION variables. 
     Old version of DLAB 2.1 called Census DIVISION
     variables "region." 

  4. Updates state-year-age specific arrests 
     variables with NEWPROARR15, NEWVIOARR15, 
     NEWMURRARR15, etc ... We delete  
     DC and WI from these updates, b/c we have 
     found that the arrests for these states
     look bad. We also see below that the MN
     data for 1997 do not match the DLAB 2.1 data
     very well, so we delete that as well. You can 
     comment these lines out and re-run this program 
     if you would like to investigate these data yourself.

  The key new variables added to DLAB 2.1.DTA are:

  censpop  - state-year pop from census 
  seerpop  - state-year pop from seer 
  viol_fg06 - total violent crime incidents from crime reports
  murd_fg06 - total murders from crime reports
  prop_fg06 - total property crime incidents from crime reports
  newlpc_viol - new per capita violent crime rate
  newlpc_murd - new per capita murder rate 
  newlpc_prop - new per capita property crime rate 
  newefaprop  - new 'effective abortion rate' for 
                property crime
  newefaviol  - new 'effective abortion rate' for 
                violent crime
  newefamurd  - new 'effective abortion rate' for 
                murder
  newproarrX  - new property crime arrests 
                for age X, from 15 to 24
  newvioarrX  - new violent crime arrests 
                for age X, from 15 to 24
  newmurarrX  - new murder arrests 
                for age X, from 15 to 24
  region      - Census Region (4 of these)
  division    - Census Division (9 of these -- DLAB 2.1 
                called this variable 'region')
  abort7084   - mean of abresrt     from 1970 to 1984
  prop7084    - mean of newlpc_prop from 1970 to 1984
  viol7084    - mean of newlpc_viol from 1970 to 1984
  murd7084    - mean of newlpc_murd from 1970 to 1984
 N.B. -- if you run this program with Stata 
 version 7, you may get a 'type mismatch'   
 error when appending the state-level Stata 
 datasets together, b/c the string variables
 for STATENAME are different lengths. Stata 
 8 does not have a problem with this. 

******************************************* */      

#delimit ;
clear ;

set mem 100m;
set matsize 800;
version 8.2;

/* *************************************** */
/* 1. Read in state-level crime data from  */
/*    individual spreadsheets (.csv files) */
/* *************************************** */

local states alabama alaska arizona arkansas california colorado connecticut /*
             */delaware dc florida georgia hawaii idaho illinois indiana iowa kansas /* 
             */kentucky louisiana maine maryland massachusetts michigan minnesota /*
             */mississippi missouri montana nebraska nevada newhampshire newjersey /*
             */newmexico newyork northcarolina northdakota ohio oklahoma oregon /*
             */pennsylvania rhodeisland southcarolina southdakota tennessee texas /*
             */utah vermont virginia washington westvirginia wisconsin wyoming;

disp " `states' ";
local numstatesin_states : word count `states';
disp `numstatesin_states';

foreach s of local states {;
   insheet using crimedata/`s'.csv, clear; 
   gen statename = "`s'";
   keep year statename population violentcrimetotal murderandnonnegligentmanslaughte propertycrimetotal;
   rename population crimepop;
   rename violentcrimetotal viol_fg06;
   rename murderandnonnegligentmanslaughte murd_fg06;
   rename propertycrimetotal prop_fg06;
   save `s'.dta, replace;
   };

* 'Use' the first state (Alabama), then append all the others. 
* Clean up the state-level .dta files after we append them to 
* larger dataset. Note that we go through a macro as before, but 
* we remove 'alabama' from the STATES macro by using the 
* -subinstr- command to replace 'alabama' with an empty string ;

use alabama.dta, clear;

local states2: subinstr local states "alabama" "";
macro drop states;

disp " `states2' ";
local numstatesin_states2 : word count `states2';
disp `numstatesin_states2';

foreach s2 of local states2 {;
   append using `s2'.dta;
   erase `s2'.dta;
   };

erase alabama.dta;  * Don't forget to clean up this one! ;
macro drop states2;

label var viol_fg06 "Violent crime total FG06";
label var prop_fg06 "Property crime total FG06";
label var murd_fg06 "Murder & non-negl manslgtr total FG06";

replace year = year - 1900;

* Write FIPS (Federal Information Processing System) designation 
* for each state ;

gen fips = 999;

replace fips =  01 if statename == "alabama"; 
replace fips =  02 if statename == "alaska"; 
replace fips =  04 if statename == "arizona"; 
replace fips =  05 if statename == "arkansas"; 
replace fips =  06 if statename == "california"; 
replace fips =  08 if statename == "colorado"; 
replace fips =  09 if statename == "connecticut"; 
replace fips =  10 if statename == "delaware"; 
replace fips =  11 if statename == "dc"; 
replace fips =  12 if statename == "florida"; 
replace fips =  13 if statename == "georgia"; 
replace fips =  15 if statename == "hawaii"; 
replace fips =  16 if statename == "idaho"; 
replace fips =  17 if statename == "illinois"; 
replace fips =  18 if statename == "indiana"; 
replace fips =  19 if statename == "iowa"; 
replace fips =  20 if statename == "kansas"; 
replace fips =  21 if statename == "kentucky";
replace fips =  22 if statename == "louisiana"; 
replace fips =  23 if statename == "maine"; 
replace fips =  24 if statename == "maryland"; 
replace fips =  25 if statename == "massachusetts"; 
replace fips =  26 if statename == "michigan"; 
replace fips =  27 if statename == "minnesota"; 
replace fips =  28 if statename == "mississippi"; 
replace fips =  29 if statename == "missouri"; 
replace fips =  30 if statename == "montana"; 
replace fips =  31 if statename == "nebraska"; 
replace fips =  32 if statename == "nevada"; 
replace fips =  33 if statename == "newhampshire"; 
replace fips =  34 if statename == "newjersey"; 
replace fips =  35 if statename == "newmexico"; 
replace fips =  36 if statename == "newyork";
replace fips =  37 if statename == "northcarolina"; 
replace fips =  38 if statename == "northdakota"; 
replace fips =  39 if statename == "ohio"; 
replace fips =  40 if statename == "oklahoma"; 
replace fips =  41 if statename == "oregon"; 
replace fips =  42 if statename == "pennsylvania"; 
replace fips =  44 if statename == "rhodeisland"; 
replace fips =  45 if statename == "southcarolina"; 
replace fips =  46 if statename == "southdakota"; 
replace fips =  47 if statename == "tennessee"; 
replace fips =  48 if statename == "texas";
replace fips =  49 if statename == "utah"; 
replace fips =  50 if statename == "vermont"; 
replace fips =  51 if statename == "virginia"; 
replace fips =  53 if statename == "washington"; 
replace fips =  54 if statename == "westvirginia"; 
replace fips =  55 if statename == "wisconsin"; 
replace fips =  56 if statename == "wyoming";

drop statename;
tab fips;

sort fips year;
tsset fips year;

desc;
summ;

save allstates, replace;
clear;

/* ************************************************ */
/* 2. Now merge in the population data. There is a  */
/*    population variable on the crime data (which  */
/*    we have renamed CRIMEPOP) but it doesn't look */
/*    like it has been revised over time, and it    */
/*    doesn't look like DL used it for their series,*/
/*    so we drop it. We'll merge in both SEER and   */
/*    raw CENSUS state-level population estimates.  */
/*    Unlike the state-age-year data, SEER and      */
/*    CENSUS look pretty close aggregated up to the */ 
/*    state-year level.                             */
/* ************************************************ */

* Start with SEER population. Have to aggregate across 
* all ages to get an overall state-year population estimate; 

use popdata/seer/seerpop; 

sort fips year;
collapse (sum) seerpop, by(fips year);

replace year = year - 1900;
sort fips year;
desc;
save seer, replace;
clear;

* Merge in CENSUS population, which comes from the    
* HAVER database;

insheet using "popdata/census/Census Populations Edited.txt" , names;

reshape long censpop, i(stabbrev) j(year);

gen fips = 999;

replace fips =  01 if stabbrev == "AL"; 
replace fips =  02 if stabbrev == "AK"; 
replace fips =  04 if stabbrev == "AZ"; 
replace fips =  05 if stabbrev == "AR"; 
replace fips =  06 if stabbrev == "CA"; 
replace fips =  08 if stabbrev == "CO"; 
replace fips =  09 if stabbrev == "CT"; 
replace fips =  10 if stabbrev == "DE"; 
replace fips =  11 if stabbrev == "DC"; 
replace fips =  12 if stabbrev == "FL"; 
replace fips =  13 if stabbrev == "GA"; 
replace fips =  15 if stabbrev == "HI"; 
replace fips =  16 if stabbrev == "ID"; 
replace fips =  17 if stabbrev == "IL"; 
replace fips =  18 if stabbrev == "IN"; 
replace fips =  19 if stabbrev == "IA"; 
replace fips =  20 if stabbrev == "KS"; 
replace fips =  21 if stabbrev == "KY";
replace fips =  22 if stabbrev == "LA"; 
replace fips =  23 if stabbrev == "ME"; 
replace fips =  24 if stabbrev == "MD"; 
replace fips =  25 if stabbrev == "MA"; 
replace fips =  26 if stabbrev == "MI"; 
replace fips =  27 if stabbrev == "MN"; 
replace fips =  28 if stabbrev == "MS"; 
replace fips =  29 if stabbrev == "MO"; 
replace fips =  30 if stabbrev == "MT"; 
replace fips =  31 if stabbrev == "NE"; 
replace fips =  32 if stabbrev == "NV"; 
replace fips =  33 if stabbrev == "NH"; 
replace fips =  34 if stabbrev == "NJ"; 
replace fips =  35 if stabbrev == "NM"; 
replace fips =  36 if stabbrev == "NY";
replace fips =  37 if stabbrev == "NC"; 
replace fips =  38 if stabbrev == "ND"; 
replace fips =  39 if stabbrev == "OH"; 
replace fips =  40 if stabbrev == "OK"; 
replace fips =  41 if stabbrev == "OR"; 
replace fips =  42 if stabbrev == "PA"; 
replace fips =  44 if stabbrev == "RI"; 
replace fips =  45 if stabbrev == "SC"; 
replace fips =  46 if stabbrev == "SD"; 
replace fips =  47 if stabbrev == "TN"; 
replace fips =  48 if stabbrev == "TX";
replace fips =  49 if stabbrev == "UT"; 
replace fips =  50 if stabbrev == "VT"; 
replace fips =  51 if stabbrev == "VA"; 
replace fips =  53 if stabbrev == "WA"; 
replace fips =  54 if stabbrev == "WV"; 
replace fips =  55 if stabbrev == "WI"; 
replace fips =  56 if stabbrev == "WY";

drop stabbrev;
tab fips;

desc;
sort fips year;
tsset fips year;

merge fips year using seer;
erase seer.dta;

tab _merge;
drop _merge;

* Merge the population data back to 
* the ALLSTATES database;

sort fips year;
tsset fips year;
merge fips year using allstates;
erase allstates.dta;

tab _merge;
drop _merge;

* Normalize and label the population data;

drop crimepop ; 

replace seerpop   = seerpop/1000;
* replace censpop   = censpop; * NOTE: no need divide CENSPOP again;

label var seerpop  "State-level SEER pop FG06";
label var censpop  "State-level Census pop FG06";

* Now that we have all the population variables we need, 
* write the per-capita crime rates. Use CENSUS population 
* as the denominator, b/c it is virtually identical to 
* SEER, starts earlier than 1969, and runs past 2002 
* to 2003; 

gen newlpc_viol       = ln(viol_fg06/censpop);
gen newlpc_murd       = ln(murd_fg06/censpop);
gen newlpc_prop       = ln(prop_fg06/censpop);

sort fips year;
tsset fips year;

save allstates2, replace;
clear;

/* ************************************************ */
/* 3. Now write the NEWEFA variables -- these are   */
/*    constructed with the same weights as the EFA  */
/*    variables in DL (2001), but using abortions   */
/*    for residents of the state (ABRESRT) rather   */
/*    than than abortions used in the original      */
/*    DL (2001) paper, which was called ABORT       */
/* ************************************************ */

use "../DLdata/dlab 2.1.dta", clear;

sort fips year;
tsset fips year;

merge fips year using allstates2.dta;
erase allstates2.dta;
tab _merge;
drop _merge; 

* It's good to get a count of the variables in this
* dataset now -- since we will EXPAND the dataset with
* the weights by this number below;
disp _N;

sort fips year;
tsset fips year;

save allstates3.dta, replace;
clear;

* Now merge in the EFA weights ;

infile propwt0-propwt29 using efaweights/efawt_prop.dat;
save temp, replace;
clear;

infile violwt0-violwt29 using efaweights/efawt_viol.dat;
merge using temp;
tab _merge;
drop _merge;
save temp, replace;
clear;

infile murdwt0-murdwt29 using efaweights/efawt_murd.dat;
merge using temp;
tab _merge;
drop _merge;
save temp, replace;

summ propwt0-propwt7 violwt0-violwt7 murdwt0-murdwt7;
drop propwt0-propwt7 violwt0-violwt7 murdwt0-murdwt7;

summ;

* This expands the number of observations from 1 to 2805   
* which is the number of observations in the dataset to be  
* merged below (allstates3). I'm not wild about this piece  
* of code but I couldn't figure out how to merge a single   
* observation to a dataset;
expand 2805;

merge using allstates3;
erase temp.dta;
erase allstates3.dta;

tab _merge;
drop _merge;

sort fips year;
tsset fips year;

* First regenerate the EFA variables from DL (2001)
* as a check. Note that we only create the CHECK
* variables through 1994, b/c the original EFAs
* did not have all the ABORT data they needed 
* to create the EFAs after that year ;

replace abort = 0 if abort == .;

sort fips year;
tsset fips year;

local types prop viol murd;

foreach x of local types {;
  gen efa`x'_check =   L30.abort*`x'wt29 +     
                       L29.abort*`x'wt28 +    
                       L28.abort*`x'wt27 +    
                       L27.abort*`x'wt26 +    
                       L26.abort*`x'wt25 +    
                       L25.abort*`x'wt24 +    
                       L24.abort*`x'wt23 +    
                       L23.abort*`x'wt22 +    
                       L22.abort*`x'wt21 +    
                       L21.abort*`x'wt20 +    
                       L20.abort*`x'wt19 +    
                       L19.abort*`x'wt18 +    
                       L18.abort*`x'wt17 +    
                       L17.abort*`x'wt16 +    
                       L16.abort*`x'wt15 +    
                       L15.abort*`x'wt14 +    
                       L14.abort*`x'wt13 +    
                       L13.abort*`x'wt12 +    
                       L12.abort*`x'wt11 +    
                       L11.abort*`x'wt10 +    
                       L10.abort*`x'wt9  +    
                        L9.abort*`x'wt8       
       if year >= 85 & year <= 94;            
};

replace efaprop_check = efaprop_check/100;
replace efaviol_check = efaviol_check/100;
replace efamurd_check = efamurd_check/100;

gen propdiff = efaprop - efaprop_check if year >= 85 & year <= 94;
gen violdiff = efaviol - efaviol_check if year >= 85 & year <= 94;
gen murddiff = efamurd - efamurd_check if year >= 85 & year <= 94;

summ  propdiff
      violdiff
      murddiff;

drop *check *diff;

* Now generate the NEWEFA variables; 

replace abresrt = 0 if abresrt == .;

sort fips year;
tsset fips year;

* These weights for people in early 30s come 
* from the worksheet in the EFAWEIGHTS subdirectory;

gen propwt32 = 0.0173173829930097 ;
gen propwt31 = 0.0173173829930097 ;
gen propwt30 = 0.0173173829930097 ;
				 
gen violwt32 = 0.0247057950720095 ; 
gen violwt31 = 0.0247057950720095 ; 
gen violwt30 = 0.0247057950720095 ; 
				 
gen murdwt32 = 0.0274957216200799 ;
gen murdwt31 = 0.0274957216200799 ;
gen murdwt30 = 0.0274957216200799 ;

sort fips year;
tsset fips year;

gen l33abresrt = L33.abresrt;

summ fips year l33abresrt if l33abresrt ~= .;
tab fips if l33abresrt ~= . & l33abresrt ~= 0;
tab year if l33abresrt ~= . & l33abresrt ~= 0;
drop l33abresrt;

list fips year abresrt if fips == 1 | fips == 36;

foreach x of local types {;
   gen newefa`x' =   L33.abresrt*`x'wt32 +   
                     L32.abresrt*`x'wt31 +   
                     L31.abresrt*`x'wt30 +   
                     L30.abresrt*`x'wt29 +   
                     L29.abresrt*`x'wt28 +   
                     L28.abresrt*`x'wt27 +   
                     L27.abresrt*`x'wt26 +   
                     L26.abresrt*`x'wt25 +   
                     L25.abresrt*`x'wt24 +   
                     L24.abresrt*`x'wt23 +   
                     L23.abresrt*`x'wt22 +   
                     L22.abresrt*`x'wt21 +   
                     L21.abresrt*`x'wt20 +   
                     L20.abresrt*`x'wt19 +   
                     L19.abresrt*`x'wt18 +   
                     L18.abresrt*`x'wt17 +   
                     L17.abresrt*`x'wt16 +   
                     L16.abresrt*`x'wt15 +   
                     L15.abresrt*`x'wt14 +   
                     L14.abresrt*`x'wt13 +   
                     L13.abresrt*`x'wt12 +   
                     L12.abresrt*`x'wt11 +   
                     L11.abresrt*`x'wt10 +   
                     L10.abresrt*`x'wt9 +    
                      L9.abresrt*`x'wt8      
        if year >= 85 & year <= 103;             
   drop `x'wt*;                                 
};

replace newefaprop = newefaprop/100;
replace newefaviol = newefaviol/100;
replace newefamurd = newefamurd/100;

label var newefaprop "efa_prop w/ABRESRT FG06";
label var newefaviol "efa_viol w/ABRESRT FG06";
label var newefamurd "efa_murd w/ABRESRT FG06";

label var newlpc_prop "LPC_PROP w/Cens 60-03 data FG06";
label var newlpc_viol "LPC_VIOL w/Cens 60-03 data FG06";
label var newlpc_murd "LPC_MURD w/Cens 60-03 data FG06";

/* ************************************************* */
/* 4. Rewrite the DIVISION variable (dlab calls it   */
/*    region, then write some FIPS labels            */
/* ************************************************* */

rename region olddivision;
gen division = 999;

/* Census DIVISION variable -- 9 of these */
/* New England */
replace division  = 1 if (fips==09|
                          fips==23|
                          fips==25|
                          fips==33|
                          fips==44|
                          fips==50);

/* Middle Atlantic */
replace division = 2 if (fips==34|
                         fips==36|
                         fips==42);

/* East North Central */
replace division = 3 if (fips==18|
                         fips==17|
                         fips==26|
                         fips==39|
                         fips==55);
                        
/* West North Central */
replace division = 4 if (fips==20|
                         fips==27|
                         fips==19|
                         fips==29|
                         fips==31|
                         fips==38|
                         fips==46);

/* South Atlantic */
replace division = 5 if  (fips==10| fips==11 |
                          fips==12|fips==13 |
                          fips==24|fips==37 |
                          fips==45|fips==51 |
                          fips==54);
                 
/* East South Central */
replace division = 6 if (fips==21|fips==28|
                         fips==01|fips==47);


/* West South Central */
replace division = 7 if (fips==05|fips==22|
                         fips==40|fips==48);

/* Mountain */
replace division = 8 if (fips==04|fips==08|
                          fips==16|fips==35|
                          fips==30|fips==49|
                          fips==32|fips==56);

/* Pacific */ 
replace division = 9 if (fips==02|fips==06|
                          fips==15|fips==41|
                          fips==53);

egen maxolddivision  = max(olddivision), by(fips);
replace olddivision = maxolddivision;
tab olddivision division;
drop maxolddivision olddivision;

/* Census REGION variable -- 4 of these */

gen region = 999;
replace region = 1 if division == 1 | division == 2;
replace region = 2 if division == 3 | division == 4;
replace region = 3 if division == 5 | division == 6 | division == 7;
replace region = 4 if division == 8 | division == 9;


label def divlbl  01 "New England"
                  02 "Middle Atlantic"
                  03 "East North Central"
                  04 "West North Central" 
                  05 "South Atlantic"
                  06 "East South Central" 
                  07 "West South Central" 
                  08 "Mountain" 
                  09 "Pacific" ;


label def reglbl  01 "Northeast"
                  02 "Midwest"
                  03 "South"
                  04 "West";

label def fipslbl 01  "AL"
  		  02  "AK"
  		  04  "AZ"
  		  05  "AR"
  		  06  "CA"
  		  08  "CO"
  		  09  "CT"
  		  10  "DE"
  		  11  "DC"
  		  12  "FL"
  		  13  "GA"
  		  15  "HI"
  		  16  "ID"
  		  17  "IL"
  		  18  "IN"
  		  19  "IA"
  		  20  "KS"
  		  21  "KY"
 		  22  "LA"
  		  23  "ME"
  		  24  "MD"
  		  25  "MA"
  		  26  "MI"
  		  27  "MN"
  		  28  "MS"
  		  29  "MO"
  		  30  "MT"
  		  31  "NE"
  		  32  "NV"
  		  33  "NH"
  		  34  "NJ"
  		  35  "NM"
  		  36  "NY"
 		  37  "NC"
  		  38  "ND"
  		  39  "OH"
  		  40  "OK"
  		  41  "OR"
  		  42  "PA"
  		  44  "RI"
  		  45  "SC"
  		  46  "SD"
  		  47  "TN"
  		  48  "TX"
 		  49  "UT"
  		  50  "VT"
  		  51  "VA"
  		  53  "WA"
  		  54  "WV"
  		  55  "WI"
  		  56  "WY";

label values fips     fipslbl;
label values division divlbl;
label values region   reglbl;

label var year "2-digit year indicator, 1950-2004";
label var division "Census Division (DL calls it region)";
label var region "Census Region";

tab division;
sort division;
by division: tab fips;

tab region;
sort region;
by region: tab division;

tab fips state;

sort fips year;
tsset fips year;

* Make sure REPEAL and STATENUM encompasses all years 
* of expanded dataset ;

egen maxrepeal = max(repeal), by(fips);
replace repeal = maxrepeal;
drop maxrepeal;
tab fips repeal;

egen maxstatenum = max(statenum), by(fips);
replace statenum = maxstatenum;
drop maxstatenum;

/* ************************************************ */
/* 5. Update the state-year-age arrest data         */
/* Again, we dropped DC and WI from these data      */ 
/* before writing the final version. The checks     */
/* below indicate that the data for MN for 1997 is  */
/* suspect, so we delete those data, too.           */
/* ************************************************ */

sort fips year;
merge fips year using arrests/newarrests_wide;
tab _merge;
drop _merge;

sort fips year;
tsset fips year;

preserve;

* Check the years of overlap, note problems with MN in 1997;

keep if year == 97 | year == 98;

keep fips year proarr* vioarr* murarr* newproarr* newvioarr* newmurarr* ;

reshape long proarr vioarr murarr newproarr newvioarr newmurarr, j(age) i(fips year);

summ;

gen propdiff = 100*(newproarr - proarr)/proarr;
gen violdiff = 100*(newvioarr - vioarr)/vioarr;
gen murddiff = 100*(newmurarr - murarr)/murarr;

tab propdiff if year == 97;
tab propdiff if year == 98;
 list fips year age proarr newproarr propdiff if propdiff ~= 0 & propdiff ~= .;

tab violdiff if year == 97;
tab violdiff if year == 98;
 list fips year age vioarr newvioarr violdiff if violdiff ~= 0 & violdiff ~= .;

tab murddiff if year == 97;
tab murddiff if year == 98;
 list fips year age murarr newmurarr murddiff if murddiff ~= 0 & murddiff ~= .;

drop *diff;

* Delete bad data ;

restore;

foreach x of numlist 15/24 {;
  replace newproarr`x' = . if (fips == 11 | fips == 55) & year >= 97;   
  replace newvioarr`x' = . if (fips == 11 | fips == 55) & year >= 97;   
  replace newmurarr`x' = . if (fips == 11 | fips == 55) & year >= 97;   
                                                                     
  replace newproarr`x' = . if (fips == 27) & year == 97;                
  replace newvioarr`x' = . if (fips == 27) & year == 97;                
  replace newmurarr`x' = . if (fips == 27) & year == 97;                
};


sort fips year;
tsset fips year;

* Write some useful 70-84 means and save final version of dataset;

egen arate     = mean(abresrt)     if year >= 70 & year <= 84, by(fips);
egen abort7084 = max(arate), by(fips);

egen prate     = mean(newlpc_prop) if year >= 70 & year <= 84, by(fips);
egen prop7084  = max(prate), by(fips);

egen vrate     = mean(newlpc_viol) if year >= 70 & year <= 84, by(fips);
egen viol7084  = max(vrate), by(fips);

egen mrate     = mean(newlpc_murd) if year >= 70 & year <= 84, by(fips);
egen murd7084  = max(mrate), by(fips);

drop arate prate vrate mrate;

list fips year abort7084 prop7084 viol7084 murd7084 if year == 50 | year == 104;

sort fips year;
tsset fips year;

save dlab_fg06, replace;

desc new*;
desc;
summ;

exit, clear;
