options ls=125 ps=92 dquote;
title1 'STPOP.SAS -- Census population-by-age data for indiv states (80s & 90s)';
************************************************************
* 
************************************************************;

libname sasdata 'data';

* * * * * * * * * * * * * * * * * * * * * * * * * * * * ;
* 1980s data ;

%macro read80s(indata,outdata,year);
data &outdata;
  infile "&indata" missover;
  input fips state $ age total; * men women;
  stname = stnamel(state);
  year = &year;
  run;
%mend read80s;

%read80s(1980_st/stiag780.edit,d1980,1980);
%read80s(1980_st/stiag781.edit,d1981,1981);
%read80s(1980_st/stiag782.edit,d1982,1982);
%read80s(1980_st/stiag783.edit,d1983,1983);
%read80s(1980_st/stiag784.edit,d1984,1984);
%read80s(1980_st/stiag785.edit,d1985,1985);
%read80s(1980_st/stiag786.edit,d1986,1986);
%read80s(1980_st/stiag787.edit,d1987,1987);
%read80s(1980_st/stiag788.edit,d1988,1988);
%read80s(1980_st/stiag789.edit,d1989,1989);

data all1980;  
  set d1980
      d1981
      d1982
      d1983
      d1984
      d1985
      d1986
      d1987
      d1988
      d1989;

  agegroup = " ";

proc delete data = d1980 d1981 d1982 d1983 d1984 
                   d1985 d1986 d1987 d1988 d1989 ;

proc sort data = all1980; by fips year age;

proc freq data = all1980;
  tables age year stname state fips;
  title2 'Proc Freq for original 1980s data';
  run;

proc Means data = all1980;
  title2 'Proc Means on original 1980s data';
  run;

* * * * * * * * * * * * * * * * * * * * * * * * * * * * ;
* 1990s data ;

%macro read90s(indata,outdataus,outtots,outdata,year);
data &outdataus &outtots &outdata;
  infile "&indata" missover;
  informat total comma11.;
  input fips 1-2 stname $ 4-24 char_age $ 25-27 total; * men women ;
  if fips ~= 0 then state = fipstate(fips); else state = "US";
  year = &year;

  if char_age = '85+' then char_age =  '85';
  if char_age = 'AA'  then char_age =  '99';

  * Convert character ages to numeric ages;
  age=input(char_age,best4.);
  drop char_age;

  if age = 99 then age = 999;

  if fips  = 00              then output &outdataus; else 
  if fips ~= 00 & age = 999  then output &outtots; else 
  if fips ~= 00 & age ~= 999 then output &outdata;

  run;
%mend read90s;

* note the 'backwards' yearly naming conventions 
* for these files;
%read90s(1990_st/st-99-19.edit,us1990,tot1990,d1990,1990);
%read90s(1990_st/st-99-18.edit,us1991,tot1991,d1991,1991);
%read90s(1990_st/st-99-17.edit,us1992,tot1992,d1992,1992);
%read90s(1990_st/st-99-16.edit,us1993,tot1993,d1993,1993);
%read90s(1990_st/st-99-15.edit,us1994,tot1994,d1994,1994);
%read90s(1990_st/st-99-14.edit,us1995,tot1995,d1995,1995);
%read90s(1990_st/st-99-13.edit,us1996,tot1996,d1996,1996);
%read90s(1990_st/st-99-12.edit,us1997,tot1997,d1997,1997);
%read90s(1990_st/st-99-11.edit,us1998,tot1998,d1998,1998);
%read90s(1990_st/st-99-10.edit,us1999,tot1999,d1999,1999);

data tot1990;  
  set tot1990
      tot1991
      tot1992
      tot1993
      tot1994
      tot1995
      tot1996
      tot1997
      tot1998
      tot1999;

proc delete data = tot1990 tot1991 tot1992 tot1993 tot1994 
                   tot1995 tot1996 tot1997 tot1998 tot1999 ;

data all1990;  
  set d1990
      d1991
      d1992
      d1993
      d1994
      d1995
      d1996
      d1997
      d1998
      d1999;

  agegroup = " ";

proc delete data = d1990 d1991 d1992 d1993 d1994 
                   d1995 d1996 d1997 d1998 d1999 ;

proc sort; by fips year age;

proc freq data = all1990;
  tables age year stname state fips;
  title2 'Proc Freq for original 1990s data';
  run;

proc Means data = all1990;
  title2 'Proc Means on original 1990s data';
  run;

* * * * * * * * * * * * * * * * * * * * * * * * * * * * ;
* 2000s data ;

proc import datafile='./2000_st/SC-EST2004-AGESEX_RES.edit' 
   out=one dbms=csv replace;
   getnames=yes;
   run;

data two(drop = name sumlev region division census2000 estbase2000);
  set one;
  if fips = 11 then stname = fipnamel(state);
  rename state = fips;
  if sex ~= 0 then delete;

data three(keep = age agegroup year stname state fips total);
  set two;

  agegroup = " ";

  if fips ~= 0 then state  = fipstate(fips); else state  = 'US';
  if fips ~= 0 then stname = fipnamel(fips); else stname = 'United States';
  
  year = 2000; total = popestimate2000; output;
  year = 2001; total = popestimate2001; output;
  year = 2002; total = popestimate2002; output;
  year = 2003; total = popestimate2003; output;
  year = 2004; total = popestimate2004; output;

data tot2000 all2000;
  set three;
  if fips = 0 then output tot2000; else output all2000;

proc sort data = all2000; by fips year age;

proc freq data = all2000;
  tables age year stname state fips;
  title2 'Proc Freq for original 2000s data';
  run;

proc means data = all2000;
  title2 'Proc Means on original 2000s data';
  run;

* * * * * * * ;

data sasdata.stpop;
  set all1980 all1990 all2000;
  rename total = pop;

proc freq data = sasdata.stpop;
  tables age year stname state fips;
  title2 'Proc Freq for state data (1980-2004)';
  run;

proc means;
  title2 'Proc Means on state data (1980-2004)';

proc print; where fips = 6 & (year = 1980 | year = 1990 | year = 2000);
  title2 'Printout of selected years for California';
  run;

data _null_;
  set sasdata.stpop;
  file 'data/stpop.dat';
  put fips +2 
      year +2
       age +2 
       pop;

run;
