#delimit ; 
clear;

set mem 100m;
set matsize 800;

use ../data/dlab_fg06;

replace year = year + 1900;
keep if year >= 1970 & year <= 1984;

gen pc_prop = (prop_fg06/censpop);
gen pc_viol = (viol_fg06/censpop);

sort division fips year;

collapse (mean) abresrt pc_prop pc_viol censpop, by(division fips);

list fips abresrt pc_prop pc_viol;
list fips division censpop;

/******************************************************** */
/* UNCONDITIONAL ANALYSIS                                 */

* Graphs ;

set scheme s1mono, permanently;

label var abresrt "Average Abortion Ratio";
label var pc_prop "Average Property Crime Rate";
label var pc_viol "Average Violent Crime Rate";

graph twoway (scatter pc_prop abresrt, mlabel(fips) mlabposition(0) msymbol(none)), 
         name(prop1a,replace) legend(off) t1title(Panel A: Property Crime and Abortion);
graph export eps/prop1a.eps, as(eps) orientation(landscape) replace;

graph twoway (scatter pc_viol abresrt, mlabel(fips) mlabposition(0) msymbol(none)), 
         name(viol1a,replace) legend(off) t1title(Panel B: Violent Crime and Abortion);
graph export eps/viol1a.eps, as(eps) orientation(landscape) replace;

* Regressions ; 

xi: regress pc_prop abresrt [aw=censpop], robust;
  test abresrt;

xi: regress pc_viol abresrt [aw=censpop], robust;
  test abresrt; 

xi: regress pc_prop abresrt if fips ~= 11, robust;
  test abresrt;

xi: regress pc_viol abresrt if fips ~= 11, robust;
  test abresrt;

xi: regress pc_prop abresrt, robust;
  test abresrt;

xi: regress pc_viol abresrt, robust;
  test abresrt;

/* ***************************************************** */
/* CONDITIONAL ANALYSIS                                  */

* Whitening regressions - weighted;

qui xi: regress abresrt i.division [aw=censpop];
  predict abresidw, resid;

qui xi: regress pc_prop i.division [aw=censpop];
  predict propresidw, resid;

qui xi: regress pc_viol i.division [aw=censpop];
  predict violresidw, resid;

* Whitening regressions - unweighted;

qui xi: regress abresrt i.division;
  predict abresid, resid;

qui xi: regress pc_prop i.division;
  predict propresid, resid;

qui xi: regress pc_viol i.division;
  predict violresid, resid;

* Whitening regressions - unweighted no DC;

qui xi: regress abresrt i.division if fips ~= 11;
  predict abresidno11, resid;

qui xi: regress pc_prop i.division if fips ~= 11;
  predict propresidno11, resid;

qui xi: regress pc_viol i.division if fips ~= 11;
  predict violresidno11, resid;

* Graphs ;

label var abresid   "Conditional Average Abortion Ratio";
label var propresid "Conditional Average Property Crime Rate";
label var violresid "Conditional Average Violent Crime Rate";

graph twoway (scatter propresid abresid, mlabel(fips) mlabposition(0) msymbol(none)), 
         name(prop1b,replace) legend(off) t1title("Panel A: Property Crime and Abortion, Conditional on Census Division");
graph export eps/prop1b.eps, as(eps) orientation(landscape) replace;

graph twoway (scatter violresid abresid, mlabel(fips) mlabposition(0) msymbol(none)), 
         name(viol1b,replace) legend(off) t1title("Panel B: Violent Crime and Abortion, Conditional on Census Division");
graph export eps/viol1b.eps, as(eps) orientation(landscape) replace;

graph combine prop1a viol1a prop1b viol1b , cols(2);

graph export eps/rsquares.eps, as(eps) orientation(landscape) replace;

* Regressions ;

xi: regress propresidw abresidw [aw=censpop], robust;
  test abresidw;

xi: regress violresidw abresidw [aw=censpop], robust;
  test abresidw; 

xi: regress propresidno11 abresidno11 if fips ~= 11, robust;
  test abresidno11;

xi: regress violresidno11 abresidno11 if fips ~= 11, robust;
  test abresidno11;

xi: regress propresid abresid, robust;
  test abresid;

xi: regress violresid abresid, robust;
  test abresid;

* Run in one-step as a check ;

xi: regress pc_prop abresrt i.division [aw=censpop], robust;
  test abresrt;

xi: regress pc_viol abresrt i.division [aw=censpop], robust;
  test abresrt; 

xi: regress pc_prop abresrt i.division if fips ~= 11, robust;
  test abresrt;

xi: regress pc_viol abresrt i.division if fips ~= 11, robust;
  test abresrt;

xi: regress pc_prop abresrt i.division, robust;
  test abresrt;

xi: regress pc_viol abresrt i.division, robust;
  test abresrt;

exit, clear;
