/* ****************************************** */
/* CLUSTER.DO                                 */
/*                                            */
/* Clusters state-year-age regressions by     */
/* various methods                            */
/* ****************************************** */

drop _all 
set more 1 
set memory 1g
set matsize 8000 

*
* Now use adjusted data from DL (2006) 
* ;

#delimit ;
use ../../../data/adata;
summ;

keep if year >= 1985 & year <= 1998;

gen l_prop_pc_s = ln(proparr/seerpop);
gen l_viol_pc_s = ln(violarr/seerpop);

list fips year age censuspop seerpop if fips == 1 & year == 1998;

gen stateyear  = 100000*fips  + year;
gen stateage   = 100000*fips  + age;

summ yobstate stateyear stateage;

/* Property Crime ************************************ */

xi: reg l_prop_pc_s hist_abt    i.fips*i.year i.fips*i.age i.age*i.year [aw=popul];
xi: reg l_prop_pc_s hist_abt    i.fips*i.year i.fips*i.age i.age*i.year [aw=popul] , robust;
xi: reg l_prop_pc_s hist_abt    i.fips*i.year i.fips*i.age i.age*i.year [aw=popul] , cluster(yobstate);
xi: reg l_prop_pc_s hist_abt    i.fips*i.year i.fips*i.age i.age*i.year [aw=popul] , cluster(stateyear);
xi: reg l_prop_pc_s hist_abt    i.fips*i.year i.fips*i.age i.age*i.year [aw=popul] , cluster(stateage);
xi: reg l_prop_pc_s hist_abt    i.fips*i.year i.fips*i.age i.age*i.year [aw=popul] , cluster(fips);
			      						       
/* Violent Crime ************************************* */				       

xi: reg l_viol_pc_s hist_abt    i.fips*i.year i.fips*i.age i.age*i.year [aw=popul];
xi: reg l_viol_pc_s hist_abt    i.fips*i.year i.fips*i.age i.age*i.year [aw=popul] , robust;
xi: reg l_viol_pc_s hist_abt    i.fips*i.year i.fips*i.age i.age*i.year [aw=popul] , cluster(yobstate);
xi: reg l_viol_pc_s hist_abt    i.fips*i.year i.fips*i.age i.age*i.year [aw=popul] , cluster(stateyear);
xi: reg l_viol_pc_s hist_abt    i.fips*i.year i.fips*i.age i.age*i.year [aw=popul] , cluster(stateage);
xi: reg l_viol_pc_s hist_abt    i.fips*i.year i.fips*i.age i.age*i.year [aw=popul] , cluster(fips);
											       



exit, clear;
