#delimit ; 
clear;

set mem 100m;
set matsize 800;

use ~/.ifs4/fg_mar07/data/dlab_fg06;

replace year = year + 1900;
keep if year >= 1970 & year <= 1984;

gen pc_prop = (prop_fg06/censpop);
gen pc_viol = (viol_fg06/censpop);

sort division fips year;

collapse (mean) abresrt pc_prop pc_viol censpop, by(division fips);

list fips abresrt pc_prop pc_viol;
list fips division censpop       ;

/******************************************************** */
/* Unconditional regressions                              */

xi: regress pc_prop abresrt                     [aw=censpop], robust;  test abresrt;
xi: regress pc_prop abresrt if fips ~= 11                   , robust;  test abresrt;
xi: regress pc_prop abresrt                                 , robust;  test abresrt;

xi: regress pc_viol abresrt                     [aw=censpop], robust;  test abresrt;
xi: regress pc_viol abresrt if fips ~= 11                   , robust;  test abresrt;
xi: regress pc_viol abresrt                                 , robust;  test abresrt;

/* ***************************************************** */
/* Conditional on Census Division                        */

* Whitening regressions - weighted;

qui xi: regress abresrt i.division [aw=censpop] ; predict abresidw,   resid;
qui xi: regress pc_prop i.division [aw=censpop] ; predict propresidw, resid;
qui xi: regress pc_viol i.division [aw=censpop] ; predict violresidw, resid;

* Whitening regressions - unweighted no DC;

qui xi: regress abresrt i.division if fips ~= 11; predict abresidno11,   resid;
qui xi: regress pc_prop i.division if fips ~= 11; predict propresidno11, resid;
qui xi: regress pc_viol i.division if fips ~= 11; predict violresidno11, resid;

* Whitening regressions - unweighted;

qui xi: regress abresrt i.division              ; predict abresid,   resid;
qui xi: regress pc_prop i.division              ; predict propresid, resid;
qui xi: regress pc_viol i.division              ; predict violresid, resid;

* Regressions ;

xi: regress propresidw    abresidw     [aw=censpop], robust; test abresidw;
xi: regress propresidno11 abresidno11 if fips ~= 11, robust; test abresidno11;
xi: regress propresid     abresid                  , robust; test abresid;

xi: regress violresidw    abresidw     [aw=censpop], robust; test abresidw;
xi: regress violresidno11 abresidno11 if fips ~= 11, robust; test abresidno11;
xi: regress violresid     abresid                  , robust; test abresid;

* Run in one-step as a check - point estimates should match, 
* inference statistics will not, b/c of the difference in 
* degrees of freedom;

xi: regress pc_prop abresrt i.division [aw=censpop] , robust; test abresrt;
xi: regress pc_prop abresrt i.division if fips ~= 11, robust; test abresrt;
xi: regress pc_prop abresrt i.division              , robust; test abresrt;

xi: regress pc_viol abresrt i.division [aw=censpop] , robust; test abresrt;
xi: regress pc_viol abresrt i.division if fips ~= 11, robust; test abresrt;
xi: regress pc_viol abresrt i.division              , robust; test abresrt;

exit, clear;
