#delimit ;

* cluster_check.do 
*
* Investigates problem with obtaining F-statistics 
* on the DIVISION-YEAR variables when cov matricies
* are clustered  
*
* Omits FIRST region and division from trend list 
* ;

use ~/.ifs4/fg_mar07/data/dlab_fg06;
replace year = year + 1900;

keep if year >= 1985 & year <= 2003;

sort fips year;
tsset fips year;

gen trend       = year - 1984;    
tab trend year;

gen trend_prop  = trend*prop7084;  
gen trend_viol  = trend*viol7084;  
gen trend_murd  = trend*murd7084;  

egen popwt = mean(censpop), by(fips);

* gen trend_r1 = (region == 1)*trend;
  gen trend_r2 = (region == 2)*trend;
  gen trend_r3 = (region == 3)*trend;
  gen trend_r4 = (region == 4)*trend;

* gen qtrend_r1 = (region == 1)*(trend^2);
  gen qtrend_r2 = (region == 2)*(trend^2);
  gen qtrend_r3 = (region == 3)*(trend^2);
  gen qtrend_r4 = (region == 4)*(trend^2);

* gen trend_d1 = (division == 1)*trend;
  gen trend_d2 = (division == 2)*trend;
  gen trend_d3 = (division == 3)*trend;
  gen trend_d4 = (division == 4)*trend;
  gen trend_d5 = (division == 5)*trend;
  gen trend_d6 = (division == 6)*trend;
  gen trend_d7 = (division == 7)*trend;
  gen trend_d8 = (division == 8)*trend;
  gen trend_d9 = (division == 9)*trend;

* gen qtrend_d1 = (division == 1)*(trend^2);
  gen qtrend_d2 = (division == 2)*(trend^2);
  gen qtrend_d3 = (division == 3)*(trend^2);
  gen qtrend_d4 = (division == 4)*(trend^2);
  gen qtrend_d5 = (division == 5)*(trend^2);
  gen qtrend_d6 = (division == 6)*(trend^2);
  gen qtrend_d7 = (division == 7)*(trend^2);
  gen qtrend_d8 = (division == 8)*(trend^2);
  gen qtrend_d9 = (division == 9)*(trend^2);

* This will be a useful macro for later;

xi i.fips i.year i.division*i.year;
 unab divyears : _IdivX*;
 summ `divyears';


/* Property Crime  ********************************************* */

* Run DIVISION-YEAR DUMMY model WITHOUT cluster;
xi: prais newlpc_prop newefaprop trend_prop i.fips i.division*i.year   [aw=popwt], weights rhotype(regress) robust;
prais newlpc_prop newefaprop trend_prop _Ifips* _Iyear* `divyears' [aw=popwt], weights rhotype(regress) robust;

  test `divyears';
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"_IdivXyea_2_1986".."_IdivXyea_9_2003"]';
  mat list mybetas;
  mat myvcv    = varcov["_IdivXyea_2_1986".."_IdivXyea_9_2003","_IdivXyea_2_1986".."_IdivXyea_9_2003"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;


* Run DIVISION-YEAR DUMMY model with cluster;
xi: prais newlpc_prop newefaprop trend_prop i.fips i.division*i.year   [aw=popwt], weights rhotype(regress) cluster(fips);
prais newlpc_prop newefaprop trend_prop _Ifips* _Iyear* `divyears' [aw=popwt], weights rhotype(regress) cluster(fips);

  test `divyears';
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"_IdivXyea_2_1986".."_IdivXyea_9_2003"]';
  mat list mybetas;
  mat myvcv    = varcov["_IdivXyea_2_1986".."_IdivXyea_9_2003","_IdivXyea_2_1986".."_IdivXyea_9_2003"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;

* Run LINEAR TRENDs model WITHOUT cluster;
xi: prais newlpc_prop newefaprop trend_prop i.fips i.year trend_r*   [aw=popwt], weights rhotype(regress) robust;

  testparm trend_r*;
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"trend_r2".."trend_r4"]';
  mat list mybetas;
  mat myvcv    = varcov["trend_r2".."trend_r4","trend_r2".."trend_r4"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;

* Run LINEAR TRENDs model with cluster;
xi: prais newlpc_prop newefaprop trend_prop i.fips i.year trend_r*   [aw=popwt], weights rhotype(regress) cluster(fips);

  testparm trend_r*;
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"trend_r2".."trend_r4"]';
  mat list mybetas;
  mat myvcv    = varcov["trend_r2".."trend_r4","trend_r2".."trend_r4"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;

* Run QUADRATIC TRENDs model WITHOUT cluster;
xi: prais newlpc_prop newefaprop trend_prop i.fips i.year trend_r* qtrend_r*  [aw=popwt], weights rhotype(regress) robust;

  testparm trend_r* qtrend_r*;
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"trend_r2".."qtrend_r4"]';
  mat list mybetas;
  mat myvcv    = varcov["trend_r2".."qtrend_r4","trend_r2".."qtrend_r4"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;

* Run QUADRATIC TRENDs model with cluster;
xi: prais newlpc_prop newefaprop trend_prop i.fips i.year trend_r* qtrend_r*   [aw=popwt], weights rhotype(regress) cluster(fips);

  testparm trend_r* qtrend_r*;
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"trend_r2".."qtrend_r4"]';
  mat list mybetas;
  mat myvcv    = varcov["trend_r2".."qtrend_r4","trend_r2".."qtrend_r4"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;

/* Violent Crime  ********************************************* */

* Run DIVISION-YEAR DUMMY model WITHOUT cluster;
xi: prais newlpc_viol newefaviol trend_viol i.fips i.division*i.year   [aw=popwt], weights rhotype(regress) robust;
prais newlpc_viol newefaviol trend_viol _Ifips* _Iyear* `divyears' [aw=popwt], weights rhotype(regress) robust;

  test `divyears';
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"_IdivXyea_2_1986".."_IdivXyea_9_2003"]';
  mat list mybetas;
  mat myvcv    = varcov["_IdivXyea_2_1986".."_IdivXyea_9_2003","_IdivXyea_2_1986".."_IdivXyea_9_2003"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;


* Run DIVISION-YEAR DUMMY model with cluster;
xi: prais newlpc_viol newefaviol trend_viol i.fips i.division*i.year   [aw=popwt], weights rhotype(regress) cluster(fips);
prais newlpc_viol newefaviol trend_viol _Ifips* _Iyear* `divyears' [aw=popwt], weights rhotype(regress) cluster(fips);

  test `divyears';
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"_IdivXyea_2_1986".."_IdivXyea_9_2003"]';
  mat list mybetas;
  mat myvcv    = varcov["_IdivXyea_2_1986".."_IdivXyea_9_2003","_IdivXyea_2_1986".."_IdivXyea_9_2003"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;

* Run LINEAR TRENDs model WITHOUT cluster;
xi: prais newlpc_viol newefaviol trend_viol i.fips i.year trend_r*   [aw=popwt], weights rhotype(regress) robust;

  testparm trend_r*;
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"trend_r2".."trend_r4"]';
  mat list mybetas;
  mat myvcv    = varcov["trend_r2".."trend_r4","trend_r2".."trend_r4"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;

* Run LINEAR TRENDs model with cluster;
xi: prais newlpc_viol newefaviol trend_viol i.fips i.year trend_r*   [aw=popwt], weights rhotype(regress) cluster(fips);

  testparm trend_r*;
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"trend_r2".."trend_r4"]';
  mat list mybetas;
  mat myvcv    = varcov["trend_r2".."trend_r4","trend_r2".."trend_r4"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;

* Run QUADRATIC TRENDs model WITHOUT cluster;
xi: prais newlpc_viol newefaviol trend_viol i.fips i.year trend_r* qtrend_r*  [aw=popwt], weights rhotype(regress) robust;

  testparm trend_r* qtrend_r*;
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"trend_r2".."qtrend_r4"]';
  mat list mybetas;
  mat myvcv    = varcov["trend_r2".."qtrend_r4","trend_r2".."qtrend_r4"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;

* Run QUADRATIC TRENDs model with cluster;
xi: prais newlpc_viol newefaviol trend_viol i.fips i.year trend_r* qtrend_r*   [aw=popwt], weights rhotype(regress) cluster(fips);

  testparm trend_r* qtrend_r*;
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"trend_r2".."qtrend_r4"]';
  mat list mybetas;
  mat myvcv    = varcov["trend_r2".."qtrend_r4","trend_r2".."qtrend_r4"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;

/* Murder  ********************************************* */

* Run DIVISION-YEAR DUMMY model WITHOUT cluster;
xi: prais newlpc_viol newefamurd trend_murd i.fips i.division*i.year   [aw=popwt], weights rhotype(regress) robust;
prais newlpc_murd newefamurd trend_murd _Ifips* _Iyear* `divyears' [aw=popwt], weights rhotype(regress) robust;

  test `divyears';
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"_IdivXyea_2_1986".."_IdivXyea_9_2003"]';
  mat list mybetas;
  mat myvcv    = varcov["_IdivXyea_2_1986".."_IdivXyea_9_2003","_IdivXyea_2_1986".."_IdivXyea_9_2003"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;


* Run DIVISION-YEAR DUMMY model with cluster;
xi: prais newlpc_murd newefamurd trend_murd i.fips i.division*i.year   [aw=popwt], weights rhotype(regress) cluster(fips);
prais newlpc_murd newefamurd trend_murd _Ifips* _Iyear* `divyears' [aw=popwt], weights rhotype(regress) cluster(fips);

  test `divyears';
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"_IdivXyea_2_1986".."_IdivXyea_9_2003"]';
  mat list mybetas;
  mat myvcv    = varcov["_IdivXyea_2_1986".."_IdivXyea_9_2003","_IdivXyea_2_1986".."_IdivXyea_9_2003"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;

* Run LINEAR TRENDs model WITHOUT cluster;
xi: prais newlpc_murd newefamurd trend_murd i.fips i.year trend_r*   [aw=popwt], weights rhotype(regress) robust;

  testparm trend_r*;
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"trend_r2".."trend_r4"]';
  mat list mybetas;
  mat myvcv    = varcov["trend_r2".."trend_r4","trend_r2".."trend_r4"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;

* Run LINEAR TRENDs model with cluster;
xi: prais newlpc_murd newefamurd trend_murd i.fips i.year trend_r*   [aw=popwt], weights rhotype(regress) cluster(fips);

  testparm trend_r*;
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"trend_r2".."trend_r4"]';
  mat list mybetas;
  mat myvcv    = varcov["trend_r2".."trend_r4","trend_r2".."trend_r4"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;

* Run QUADRATIC TRENDs model WITHOUT cluster;
xi: prais newlpc_murd newefamurd trend_murd i.fips i.year trend_r* qtrend_r*  [aw=popwt], weights rhotype(regress) robust;

  testparm trend_r* qtrend_r*;
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"trend_r2".."qtrend_r4"]';
  mat list mybetas;
  mat myvcv    = varcov["trend_r2".."qtrend_r4","trend_r2".."qtrend_r4"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;

* Run QUADRATIC TRENDs model with cluster;
xi: prais newlpc_murd newefamurd trend_murd i.fips i.year trend_r* qtrend_r*   [aw=popwt], weights rhotype(regress) cluster(fips);

  testparm trend_r* qtrend_r*;
  mat betas    = e(b);
  mat varcov   = e(V);
  mat mybetas  = betas[1,"trend_r2".."qtrend_r4"]';
  mat list mybetas;
  mat myvcv    = varcov["trend_r2".."qtrend_r4","trend_r2".."qtrend_r4"];
  mat wald     = mybetas'*inv(myvcv)*mybetas;
  mat list wald;
  mat fstat  = wald/rowsof(mybetas);
  mat list fstat;

exit, clear;
