#delimit ;
*
* REGDIV.DO --  Aggregates state-year-age data across 
*               9 DIVISIONS
*               4 REGIONS, and 
*               1 NATION
* 
* and runs corresponding (unweighted) Prais-Winsten regressions 
* ;

clear;
drop _all; 
set more 1; 
set memory 1g;
set matsize 8000 ;

**************************************************************
**************************************************************
* Replicate state-year-age regressions as a check
**************************************************************
**************************************************************
*
* Use adjusted data from DL (2006) 
* ;

use ../../../data/adata;
keep if year >= 1985 & year <= 1998;
summ;

gen l_prop_pc_s = ln(proparr/seerpop);
gen l_viol_pc_s = ln(violarr/seerpop);

xi: reg l_prop_pc_s hist_abt i.fips*i.year i.fips*i.age i.age*i.year [aw=popul], cluster(fips);
xi: reg l_viol_pc_s hist_abt i.fips*i.year i.fips*i.age i.age*i.year [aw=popul], cluster(fips);

**************************************************************
**************************************************************
* DIVISION aggregation ;
**************************************************************
**************************************************************
*
* Use adjusted data from DL (2006) 
* ;

use ../../../data/adata, clear;
keep if year >= 1985 & year <= 1998;
summ;

* Aggregate data on DIVISION level ;

gen prop_pc_s = (proparr/seerpop);
gen viol_pc_s = (violarr/seerpop);
gen yob       = year - age;

drop if prop_pc_s == . | viol_pc_s == .;

sort division year age;

collapse (mean) prop_pc_s viol_pc_s hist_abt yob [fw=seerpop], by(division year age);

gen divisionage  = division*10000+age;
gen divisionyear = division*10000+year;
gen divisionyob  = division*10000+yob;

gen l_prop_pc_s = ln(prop_pc_s);
gen l_viol_pc_s = ln(viol_pc_s);

summ;

sort divisionage year;
tsset divisionage year;

save division, replace;

* Property crime -- division;
xi: prais l_prop_pc_s hist_abt  i.division*i.year i.age*i.year i.age*i.division, cluster(divisionyob);

* Violent crime -- division;
xi: prais l_viol_pc_s hist_abt  i.division*i.year i.age*i.year i.age*i.division, cluster(divisionyob);

**************************************************************
**************************************************************
* REGION aggregation ;
**************************************************************
**************************************************************
*
* Use adjusted data from DL (2006) 
* ;

use ../../../data/adata, clear;
keep if year >= 1985 & year <= 1998;
summ;

* Aggregate data on REGION level ;

gen prop_pc_s = (proparr/seerpop);
gen viol_pc_s = (violarr/seerpop);
gen yob       = year - age;

drop if prop_pc_s == . | viol_pc_s == .;

sort region year age;

collapse (mean) prop_pc_s viol_pc_s hist_abt yob [fw=seerpop], by(region year age);

gen regionage  = region*10000+age;
gen regionyear = region*10000+year;
gen regionyob  = region*10000+yob;

gen l_prop_pc_s = ln(prop_pc_s);
gen l_viol_pc_s = ln(viol_pc_s);

summ;

sort regionage year;
tsset regionage year;

save region, replace;

* Property crime -- region;
xi: prais l_prop_pc_s hist_abt  i.region*i.year i.age*i.year i.age*i.region, cluster(regionyob);

* Violent crime -- region;
xi: prais l_viol_pc_s hist_abt  i.region*i.year i.age*i.year i.age*i.region, cluster(regionyob);

**************************************************************
**************************************************************
* NATION aggregation ;
**************************************************************
**************************************************************
*
* Use adjusted data from DL (2006) 
* ;

use ../../../data/adata, clear;
keep if year >= 1985 & year <= 1998;
summ;

gen nation = 1;

* Aggregate data on NATION level ;

gen prop_pc_s = (proparr/seerpop);
gen viol_pc_s = (violarr/seerpop);
gen yob       = year - age;

drop if prop_pc_s == . | viol_pc_s == .;

sort nation year age;

collapse (mean) prop_pc_s viol_pc_s hist_abt yob [fw=seerpop], by(nation year age);

gen nationage  = nation*10000+age;
gen nationyear = nation*10000+year;
gen nationyob  = nation*10000+yob;

gen l_prop_pc_s = ln(prop_pc_s);
gen l_viol_pc_s = ln(viol_pc_s);

summ;

sort nationage year;
tsset nationage year;

save nation, replace;

* Property crime -- nation;
xi: prais l_prop_pc_s hist_abt i.year i.age, cluster(nationyob);

* Violent crime -- nation;
xi: prais l_viol_pc_s hist_abt i.year i.age, cluster(nationyob);



