log using dlabo.log, replace
drop _all 
set more 1 
set mem 10m
set mat 400 

/*The Impact of Legalized Abortion on Crime*/
/*John J. Donohue III and Steven D. Levitt*/
/*Tables 1-7*/

/* ***************************************************** */
/* Table 1 */

/*Top Panel - % Changes in Crime */

/*--------------*/
/*Period 1976-82*/
clear 
use dlabo
keep state statenum year popul lpc_*
sort statenum year

/*Keeping the Pertinent Years*/
drop if year!=76&year!=82&year!=85

/*Creating a Variable to Weight by 1985 Population*/
gen pop85=popul if year==85
replace pop85=popul[_n+2] if year==76
replace pop85=popul[_n+1] if year==82
drop if year==85

/*Creating a dummy variable for Early Legalizers*/
gen byte earlydum=1 if statenum==2|statenum==5|statenum==12|statenum==33|statenum==48
replace earlydum=0 if earlydum==.

/*Results for Column 1*/

/*Violent Crime*/
gen violdiff=lpc_viol[_n]-lpc_viol[_n-1] if statenum==statenum[_n-1]
/*Early Legalizers*/
sum violdiff if earlydum==1 [aw=pop85]
/*Rest of U.S.*/
sum violdiff if earlydum==0 [aw=pop85]
/*Difference & SE*/
regress violdiff earlydum [aw=pop85] if statenum==statenum[_n-1]

/*Property Crime*/
gen propdiff=lpc_prop[_n]-lpc_prop[_n-1] if statenum==statenum[_n-1]
/*Early Legalizers*/
sum propdiff if earlydum==1 [aw=pop85]
/*Rest of U.S.*/
sum propdiff if earlydum==0 [aw=pop85]
/*Difference & SE*/
regress propdiff earlydum [aw=pop85] if statenum==statenum[_n-1]

/*Murder*/
gen murddiff=lpc_murd[_n]-lpc_murd[_n-1] if statenum==statenum[_n-1]
/*Early Legalizers*/
sum murddiff if earlydum==1 [aw=pop85]
/*Rest of U.S.*/
sum murddiff if earlydum==0 [aw=pop85]
/*Difference & SE*/
regress murddiff earlydum [aw=pop85] if statenum==statenum[_n-1]

/*--------------*/
/*Period 1982-88*/
clear 
use dlabo
keep state statenum year popul lpc_*
sort statenum year

/*Keeping the Pertinent Years*/
drop if year!=82&year!=85&year!=88

/*Creating a Variable to Weight by 1985 Population*/
gen pop85=popul if year==85
replace pop85=popul[_n+1] if year==82
replace pop85=popul[_n-1] if year==88
drop if year==85

/*Creating a dummy variable for Early Legalizers*/
gen byte earlydum=1 if statenum==2|statenum==5|statenum==12|statenum==33|statenum==48
replace earlydum=0 if earlydum==.

/*Results for Column 2*/

/*Violent Crime*/
gen violdiff=lpc_viol[_n]-lpc_viol[_n-1] if statenum==statenum[_n-1]
/*Early Legalizers*/
sum violdiff if earlydum==1 [aw=pop85]
/*Rest of U.S.*/
sum violdiff if earlydum==0 [aw=pop85]
/*Difference & SE*/
regress violdiff earlydum [aw=pop85] if statenum==statenum[_n-1]

/*Property Crime*/
gen propdiff=lpc_prop[_n]-lpc_prop[_n-1] if statenum==statenum[_n-1]
/*Early Legalizers*/
sum propdiff if earlydum==1 [aw=pop85]
/*Rest of U.S.*/
sum propdiff if earlydum==0 [aw=pop85]
/*Difference & SE*/
regress propdiff earlydum [aw=pop85] if statenum==statenum[_n-1]

/*Murder*/
gen murddiff=lpc_murd[_n]-lpc_murd[_n-1] if statenum==statenum[_n-1]
/*Early Legalizers*/
sum murddiff if earlydum==1 [aw=pop85]
/*Rest of U.S.*/
sum murddiff if earlydum==0 [aw=pop85]
/*Difference & SE*/
regress murddiff earlydum [aw=pop85] if statenum==statenum[_n-1]

/*--------------*/
/*Period 1988-94*/
clear 
use dlabo
keep state statenum year popul lpc_*
sort statenum year

/*Keeping the Pertinent Years*/
drop if year!=85&year!=88&year!=94

/*Creating a Variable to Weight by 1985 Population*/
gen pop85=popul if year==85
replace pop85=popul[_n-1] if year==88
replace pop85=popul[_n-2] if year==94
drop if year==85

/*Creating a dummy variable for Early Legalizers*/
gen byte earlydum=1 if statenum==2|statenum==5|statenum==12|statenum==33|statenum==48
replace earlydum=0 if earlydum==.

/*Results for Column 3*/

/*Violent Crime*/
gen violdiff=lpc_viol[_n]-lpc_viol[_n-1] if statenum==statenum[_n-1]
/*Early Legalizers*/
sum violdiff if earlydum==1 [aw=pop85]
/*Rest of U.S.*/
sum violdiff if earlydum==0 [aw=pop85]
/*Difference & SE*/
regress violdiff earlydum [aw=pop85] if statenum==statenum[_n-1]

/*Property Crime*/
gen propdiff=lpc_prop[_n]-lpc_prop[_n-1] if statenum==statenum[_n-1]
/*Early Legalizers*/
sum propdiff if earlydum==1 [aw=pop85]
/*Rest of U.S.*/
sum propdiff if earlydum==0 [aw=pop85]
/*Difference & SE*/
regress propdiff earlydum [aw=pop85] if statenum==statenum[_n-1]

/*Murder*/
gen murddiff=lpc_murd[_n]-lpc_murd[_n-1] if statenum==statenum[_n-1]
/*Early Legalizers*/
sum murddiff if earlydum==1 [aw=pop85]
/*Rest of U.S.*/
sum murddiff if earlydum==0 [aw=pop85]
/*Difference & SE*/
regress murddiff earlydum [aw=pop85] if statenum==statenum[_n-1]

/*--------------*/
/*Period 1994-97*/
clear 
use dlabo
keep state statenum year popul lpc_*
sort statenum year

/*Keeping the Pertinent Years*/
drop if year!=85&year!=94&year!=97

/*Creating a Variable to Weight by 1985 Population*/
gen pop85=popul if year==85
replace pop85=popul[_n-1] if year==94
replace pop85=popul[_n-2] if year==97
drop if year==85

/*Creating a dummy variable for Early Legalizers*/
gen byte earlydum=1 if statenum==2|statenum==5|statenum==12|statenum==33|statenum==48
replace earlydum=0 if earlydum==.

/*Results for Column 4*/

/*Violent Crime*/
gen violdiff=lpc_viol[_n]-lpc_viol[_n-1] if statenum==statenum[_n-1]
/*Early Legalizers*/
sum violdiff if earlydum==1 [aw=pop85]
/*Rest of U.S.*/
sum violdiff if earlydum==0 [aw=pop85]
/*Difference & SE*/
regress violdiff earlydum [aw=pop85] if statenum==statenum[_n-1]

/*Property Crime*/
gen propdiff=lpc_prop[_n]-lpc_prop[_n-1] if statenum==statenum[_n-1]
/*Early Legalizers*/
sum propdiff if earlydum==1 [aw=pop85]
/*Rest of U.S.*/
sum propdiff if earlydum==0 [aw=pop85]
/*Difference & SE*/
regress propdiff earlydum [aw=pop85] if statenum==statenum[_n-1]

/*Murder*/
gen murddiff=lpc_murd[_n]-lpc_murd[_n-1] if statenum==statenum[_n-1]
/*Early Legalizers*/
sum murddiff if earlydum==1 [aw=pop85]
/*Rest of U.S.*/
sum murddiff if earlydum==0 [aw=pop85]
/*Difference & SE*/
regress murddiff earlydum [aw=pop85] if statenum==statenum[_n-1]

/*--------------*/
/*Period 1982-97*/
clear 
use dlabo
keep state statenum year popul lpc_*
sort statenum year

/*Keeping the Pertinent Years*/
drop if year!=82&year!=85&year!=97

/*Creating a Variable to Weight by 1985 Population*/
gen pop85=popul if year==85
replace pop85=popul[_n+1] if year==82
replace pop85=popul[_n-1] if year==97
drop if year==85

/*Creating a dummy variable for Early Legalizers*/
gen byte earlydum=1 if statenum==2|statenum==5|statenum==12|statenum==33|statenum==48
replace earlydum=0 if earlydum==.

/*Results for Column 5*/

/*Violent Crime*/
gen violdiff=lpc_viol[_n]-lpc_viol[_n-1] if statenum==statenum[_n-1]
/*Early Legalizers*/
sum violdiff if earlydum==1 [aw=pop85]
/*Rest of U.S.*/
sum violdiff if earlydum==0 [aw=pop85]
/*Difference & SE*/
regress violdiff earlydum [aw=pop85] if statenum==statenum[_n-1]

/*Property Crime*/
gen propdiff=lpc_prop[_n]-lpc_prop[_n-1] if statenum==statenum[_n-1]
/*Early Legalizers*/
sum propdiff if earlydum==1 [aw=pop85]
/*Rest of U.S.*/
sum propdiff if earlydum==0 [aw=pop85]
/*Difference & SE*/
regress propdiff earlydum [aw=pop85] if statenum==statenum[_n-1]

/*Murder*/
gen murddiff=lpc_murd[_n]-lpc_murd[_n-1] if statenum==statenum[_n-1]
/*Early Legalizers*/
sum murddiff if earlydum==1 [aw=pop85]
/*Rest of U.S.*/
sum murddiff if earlydum==0 [aw=pop85]
/*Difference & SE*/
regress murddiff earlydum [aw=pop85] if statenum==statenum[_n-1]


/*Bottom Panel - EAR for Violent Crime at the End of the Period*/

clear 
use dlabo
sort statenum year

/*Keeping only the pertinent variables*/
keep state statenum year popul efaviol

/*Keeping only the pertinent years*/
drop if year!=85&year!=88&year!=94&year!=97

/*Creating a Variable to Weight by 1985 Population*/
gen pop85=popul if year==85
replace pop85=popul[_n-1] if year==88
replace pop85=popul[_n-2] if year==94
replace pop85=popul[_n-3] if year==97
drop if year==85

/*Creating a dummy variable for Early Legalizers*/
gen byte earlydum=1 if statenum==2|statenum==5|statenum==12|statenum==33|statenum==48
replace earlydum=0 if earlydum==.

/*Results for Column 2*/
/*1988*/
/*I. Early Legalizers */
sum efaviol [weight=pop85] if year==88&earlydum==1
/*II. Rest of U.S. */
sum efaviol [weight=pop85] if year==88&earlydum==0
/*Difference*/
regress efaviol earlydum [aw=pop85] if year==88

/*Results for Column 3*/
/*1994*/
/*I. Early Legalizers */
sum efaviol [weight=pop85] if year==94&earlydum==1
/*II. Rest of U.S. */
sum efaviol [weight=pop85] if year==94&earlydum==0
/*Difference*/
regress efaviol earlydum [aw=pop85] if year==94

/*Results for Columns 4 & 5*/
/*1997*/
/*I. Early Legalizers */
sum efaviol [weight=pop85] if year==97&earlydum==1
/*II. Rest of U.S. */
sum efaviol [weight=pop85] if year==97&earlydum==0
/*Difference*/
regress efaviol earlydum [aw=pop85] if year==97


/* ***************************************************** */
/* Table 2 */

/*Column 1*/

clear
use dlabo

/*Keeping only the important years*/
drop if year!=85&year!=97
sort statenum year

/*Creating a Variable to Weight by 1985 Population*/
gen pop85=popul if year==85
replace pop85=popul[_n-1] if year==97
drop if year==85

/*Creating a Variable for Ranking States by Abortion Frequency*/
/*(Ranked by EAR for Violent Crime in 1997)*/
gen rank=1 if efaviol<.92
replace rank=2 if efaviol>.92&efaviol<1.63
replace rank=3 if efaviol>1.63

/*Results for Column 1*/
/*Generating Fixed 1985 Pop-Wt. Avg. EAR for Violent Crime in 1997*/
/*Lowest States*/
sum efaviol [weight=pop85] if rank==1
/*Medium States*/
sum efaviol [weight=pop85] if rank==2
/*Highest States*/
sum efaviol [weight=pop85] if rank==3


/*Columns 2-4*/

/*1973-1985*/

clear
use dlabo

/*Keeping only the important years*/
drop if year!=73&year!=85&year!=97

/*Keeping only the important variables*/
keep state statenum year efaviol abort popul lpc*
sort statenum year

/*Creating a Variable to Weight by 1985 Population*/
gen pop85=popul if year==85
replace pop85=popul[_n+1] if year==73

/*Creating a Variable for Ranking States by Abortion Frequency*/
/*(Ranked by EAR for Violent Crime in 1997)*/
gen efav97=efaviol if year==97
replace efav97=efaviol[_n+1] if year==85
replace efav97=efaviol[_n+2] if year==73
drop if year==97
gen rank=1 if efav97<.92
replace rank=2 if efav97>.92&efav97<1.63
replace rank=3 if efav97>1.63

/*Results for Column 2*/
/*Violent Crime*/
gen violdiff=lpc_viol[_n]-lpc_viol[_n-1] if statenum==statenum[_n-1]
/*Lowest*/
sum violdiff if rank==1 [aw=pop85]
/*Medium*/
sum violdiff if rank==2 [aw=pop85]
/*Highest*/
sum violdiff if rank==3 [aw=pop85]

/*Results for Column 3*/
/*Property Crime*/
gen propdiff=lpc_prop[_n]-lpc_prop[_n-1] if statenum==statenum[_n-1]
/*Lowest*/
sum propdiff if rank==1 [aw=pop85]
/*Medium*/
sum propdiff if rank==2 [aw=pop85]
/*Highest*/
sum propdiff if rank==3 [aw=pop85]

/*Results for Column 4*/
/*Murder Crime*/
gen murddiff=lpc_murd[_n]-lpc_murd[_n-1] if statenum==statenum[_n-1]
/*Lowest*/
sum murddiff if rank==1 [aw=pop85]
/*Medium*/
sum murddiff if rank==2 [aw=pop85]
/*Highest*/
sum murddiff if rank==3 [aw=pop85]

/*Columns 5-7*/

/*1985-1997*/

clear
use dlabo

/*Keeping only the important years*/
drop if year!=85&year!=97

/*Keeping only the important variables*/
keep state statenum year efaviol abort popul lpc*
sort statenum year

/*Creating a Variable to Weight by 1985 Population*/
gen pop85=popul if year==85
replace pop85=popul[_n-1] if year==97

/*Creating a Variable for Ranking States by Abortion Frequency*/
/*(Ranked by EAR for Violent Crime in 1997)*/
gen efav97=efaviol if year==97
replace efav97=efaviol[_n+1] if year==85
gen rank=1 if efav97<.92
replace rank=2 if efav97>.92&efav97<1.63
replace rank=3 if efav97>1.63

/*Results for Column 5*/
/*Violent Crime*/
gen violdiff=lpc_viol[_n]-lpc_viol[_n-1] if statenum==statenum[_n-1]
/*Lowest*/
sum violdiff if rank==1 [aw=pop85]
/*Medium*/
sum violdiff if rank==2 [aw=pop85]
/*Highest*/
sum violdiff if rank==3 [aw=pop85]

/*Results for Column 6*/
/*Property Crime*/
gen propdiff=lpc_prop[_n]-lpc_prop[_n-1] if statenum==statenum[_n-1]
/*Lowest*/
sum propdiff if rank==1 [aw=pop85]
/*Medium*/
sum propdiff if rank==2 [aw=pop85]
/*Highest*/
sum propdiff if rank==3 [aw=pop85]

/*Results for Column 7*/
/*Murder Crime*/
gen murddiff=lpc_murd[_n]-lpc_murd[_n-1] if statenum==statenum[_n-1]
/*Lowest*/
sum murddiff if rank==1 [aw=pop85]
/*Medium*/
sum murddiff if rank==2 [aw=pop85]
/*Highest*/
sum murddiff if rank==3 [aw=pop85]

clear


/* ***************************************************** */
/* Table 3 */

clear
use dlabo

gen popul15=popul[_n-15] if statenum==statenum[_n-15]
gen viol=exp(lpc_viol)
gen prop=exp(lpc_prop)
gen murd=exp(lpc_murd)
gen pris=exp(xxprison)
gen police=exp(xxpolice)
gen income=exp(xxincome) 
gen afdc15=xxafdc15
gen unemp=xxunemp
gen beer=xxbeer
gen pover=xxpover
gen muro25=(mur_o25)
gen vioo25=(vio_o25)
gen proo25=(pro_o25)
gen aavu25=vio_u25*(1000/a024)
gen aapu25=pro_u25*(1000/a024)
gen aamu25=mur_u25*(1000/a024)
gen aavo25=vioo25*(1000/a25p)
gen aapo25=proo25*(1000/a25p)
gen aamo25=muro25*(1000/a25p)

keep if year>84

/* Results for Columns 1 & 2 */
sum viol-murd efaviol efaprop efamurd pris-income unemp-pover aa* [aw=popul]
/* for afdc15, weight by popul15 to take into account 15 year lag */
sum afdc15 [aw=popul15]

/* calculating standard deviations within state */ 
gen rrviol=viol 
gen rrprop=prop
gen rrmurd=murd
gen rrefav=efaviol
gen rrefap=efaprop
gen rrefam=efamurd
gen rrpris=pris
gen rrpolice=police
gen rrincome=income
gen rrafdc15=afdc15
gen rrunemp=unemp
gen rrbeer=beer
gen rrpover=pover
gen rrvu25=aavu25
gen rrpu25=aapu25
gen rrmu25=aamu25
gen rrvo25=aavo25
gen rrpo25=aapo25
gen rrmo25=aamo25

for var rr* \ new nn1-nn19: egen Y=mean(X), by(statenum)
for var nn* \ var rr*: replace Y=Y-X

/* Results for Column 3 */
sum rrviol-rrincome rrunemp-rrmo25 [aw=popul]
/* for afdc15, weight by popul15 to take into account 15 year lag */
sum rrafdc15 [aw=popul15]


/* ************************************************* */
/* Table 4 */

clear
use dlabo.dta

tab year, gen(yy) nof
tab statenum, gen(ss) nof

gen txprison=xxprison
gen txpolice=xxpolice
gen txunemp=xxunemp
gen txincome=xxincome
gen txpover=xxpover
gen txafdc=xxafdc15
gen txgunlaw=xxgunlaw
gen txbeer=xxbeer

/* Column 1*/
regress lpc_viol efav yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_viol efav yy* ss*  \ new tpc_viol tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var lpc_viol efav yy* ss* xx* \ var tpc_viol tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_viol tefa tyy* tss* [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho

/* Column 2 */
regress lpc_viol efav xx*  yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_viol efav yy* ss*  \ new tpc_viol tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_viol efav yy* ss* xx* \ var tpc_viol tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_viol tefa tx* tyy* tss* [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho

/* Column 3 */
regress lpc_prop efap yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_prop efap yy* ss*  \ new tpc_prop tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var lpc_prop efap yy* ss* xx* \ var tpc_prop tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_prop tefa tyy* tss* [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho

/* Column 4 */
regress lpc_prop efap xx*  yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_prop efap yy* ss*  \ new tpc_prop tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_prop efap yy* ss* xx* \ var tpc_prop tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_prop tefa tx* tyy* tss* [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho

/* Column 5 */
regress lpc_murd efamu yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_murd efamu yy* ss*  \ new tpc_murd tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var lpc_murd efamu yy* ss* xx* \ var tpc_murd tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_murd tefa tyy* tss*  [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho

/* Column 6 */
regress lpc_murd efamu xx*  yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_murd efamu yy* ss*  \ new tpc_murd tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_murd efamu yy* ss* xx* \ var tpc_murd tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_murd tefa tx* tyy* tss*  [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho


/* ************************************************** */
/* Table 5 */

/* Rows 1-5, 10-12 */

/* Column 1 */

regress lpc_viol efav xx*  yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_viol efav yy* ss*  \ new tpc_viol tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_viol efav yy* ss* xx* \ var tpc_viol tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
/* Results for Column 1 */
**1. baseline
regress tpc_viol tefa tx* tyy* tss* [aw=popul], robust
**2. drop NY
regress tpc_viol tefa tx* tyy* tss* [aw=popul] if statenum!=33, robust
**3. drop CA
regress tpc_viol tefa tx* tyy* tss* [aw=popul] if statenum!=5, robust
**4. drop DC
regress tpc_viol tefa tx* tyy* tss* [aw=popul] if statenum!=9, robust
**5. drop NY, CA, DC
regress tpc_viol tefa tx* tyy* tss* [aw=popul] if statenum!=33&statenum!=5&statenum!=9, robust
**10. unweighted
regress tpc_viol tefa tx* tyy* tss* , robust
**11. unweighted, drop DC
regress tpc_viol tefa tx* tyy* tss* if statenum!=9, robust
**12. unweighted, drop DC, CA, NY
regress tpc_viol tefa tx* tyy* tss* if statenum!=33&statenum!=5&statenum!=9, robust

drop tpc* tefa* tyy* tss* resid* rho

/* Column 2 */

regress lpc_prop efap xx*  yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_prop efap yy* ss*  \ new tpc_prop tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_prop efap yy* ss* xx* \ var tpc_prop tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
/* Results for Column 2 */
**1. baseline
regress tpc_prop tefa tx* tyy* tss* [aw=popul], robust
**2. drop NY
regress tpc_prop tefa tx* tyy* tss* [aw=popul] if statenum!=33, robust
**3. drop CA
regress tpc_prop tefa tx* tyy* tss* [aw=popul] if statenum!=5, robust
**4. drop DC
regress tpc_prop tefa tx* tyy* tss* [aw=popul] if statenum!=9, robust
**5. drop NY, CA, DC
regress tpc_prop tefa tx* tyy* tss* [aw=popul] if statenum!=33 & statenum!=5 & statenum!=9, robust
**10. unweighted
regress tpc_prop tefa tx* tyy* tss* , robust
**11. unweighted, drop DC
regress tpc_prop tefa tx* tyy* tss* if statenum!=9, robust
**12. unweighted, drop DC CA, NY
regress tpc_prop tefa tx* tyy* tss* if statenum!=33&statenum!=5&statenum!=9, robust

drop tpc* tefa* tyy* tss* resid* rho

/* Column 3 */

regress lpc_murd efamu xx*  yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_murd efamu yy* ss*  \ new tpc_murd tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_murd efamu yy* ss* xx* \ var tpc_murd tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
/* Results for Column 3 */
**1. baseline
regress tpc_murd tefa tx* tyy* tss* [aw=popul], robust
**2. drop NY
regress tpc_murd tefa tx* tyy* tss* [aw=popul] if statenum!=33, robust
**3. drop CA
regress tpc_murd tefa tx* tyy* tss* [aw=popul] if statenum!=5, robust
**4. drop DC
regress tpc_murd tefa tx* tyy* tss* [aw=popul] if statenum!=9, robust
**5. drop NY, CA, DC
regress tpc_murd tefa tx* tyy* tss* [aw=popul] if statenum!=33&statenum!=5&statenum!=9, robust
**10. unweighted
regress tpc_murd tefa tx* tyy* tss* , robust
**11. unweighted, drop DC
regress tpc_murd tefa tx* tyy* tss* if statenum!=9, robust
**12. unweighted, drop DC, CA, NY
regress tpc_murd tefa tx* tyy* tss* if statenum!=33&statenum!=5&statenum!=9, robust

drop tpc* tefa* tyy* tss* resid* rho


/* Row 6: Adjust "effective" abortion rate for X-state mobility */

/* Column 1 */
regress lpc_viol efamigv xx*  yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_viol efamigv yy* ss*  \ new tpc_viol tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_viol efamigv yy* ss* xx* \ var tpc_viol tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_viol tefa tx* tyy* tss* [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho

/* Column 2 */
regress lpc_prop efamigp xx*  yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_prop efamigp yy* ss*  \ new tpc_prop tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_prop efamigp yy* ss* xx* \ var tpc_prop tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_prop tefa tx* tyy* tss* [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho

/* Column 3 */
regress lpc_murd efamigm xx*  yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_murd efamigm yy* ss*  \ new tpc_murd tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_murd efamigm yy* ss* xx* \ var tpc_murd tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_murd tefa tx* tyy* tss*  [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho


/* Row 7: Include control for flow of immigrants */

generate xxfb=fb/(popul*1000)
generate txfb=xxfb

/* Column 1 */
regress lpc_viol efav xx*  yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_viol efav yy* ss*  \ new tpc_viol tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_viol efav yy* ss* xx* \ var tpc_viol tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_viol tefa tx* tyy* tss* [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho

/* Column 2 */
regress lpc_prop efap xx*  yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_prop efap yy* ss*  \ new tpc_prop tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_prop efap yy* ss* xx* \ var tpc_prop tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_prop tefa tx* tyy* tss* [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho

/* Column 3 */
regress lpc_murd efamu xx*  yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_murd efamu yy* ss*  \ new tpc_murd tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_murd efamu yy* ss* xx* \ var tpc_murd tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_murd tefa tx* tyy* tss*  [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho

drop xxfb txfb


/* Row 8: Include state specific trends  */

generate trend=year-85
for new tt1-tt51 \ var ss1-ss51: generate X=Y*trend
summ tt*

/* Column 1 */
regress lpc_viol efav xx*  yy* ss* tt*  [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_viol efav yy* ss* tt* \ new tpc_viol tefa tyy1-tyy33 tss1-tss51 ttt1-ttt51: generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_viol efav yy* ss* xx* tt1-tt51 \ var tpc_viol tefa tyy1-tyy33 tss1-tss51 tx* ttt1-ttt51: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_viol tefa tx* tyy* tss* ttt* [aw=popul], robust
drop tpc* tefa* tyy* tss* ttt* resid* rho

/* Column 2 */
regress lpc_prop efap xx*  yy* ss* tt*  [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_prop efap yy* ss* tt* \ new tpc_prop tefa tyy1-tyy33 tss1-tss51 ttt1-ttt51: generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_prop efap yy* ss* xx* tt1-tt51 \ var tpc_prop tefa tyy1-tyy33 tss1-tss51 tx* ttt1-ttt51: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_prop tefa tx* tyy* tss* ttt* [aw=popul], robust
drop tpc* tefa* tyy* tss* ttt* resid* rho

/* Column 3 */
regress lpc_murd efamu xx*  yy* ss* tt*  [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_murd efamu yy* ss* tt* \ new tpc_murd tefa tyy1-tyy33 tss1-tss51 ttt1-ttt51: generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_murd efamu yy* ss* xx* tt1-tt51 \ var tpc_murd tefa tyy1-tyy33 tss1-tss51 tx* ttt1-ttt51: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_murd tefa tx* tyy* tss* ttt* [aw=popul], robust
drop tpc* tefa* tyy* tss* ttt* resid* rho


/* Row 9: add region-year interactions */

generate regiyear=region*1000+year if year>84&year<98
tab regiyear, gen(ryy) nof

/* Column 1 */
regress lpc_viol efav xx*  ryy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_viol efav ryy* ss*  \ new tpc_viol tefa tyy1-tyy117 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_viol efav ryy* ss* xx* \ var tpc_viol tefa tyy1-tyy117 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_viol tefa tx* tyy* tss* [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho

/* Column 2 */
regress lpc_prop efap xx*  ryy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_prop efap ryy* ss*  \ new tpc_prop tefa tyy1-tyy117 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_prop efap ryy* ss* xx* \ var tpc_prop tefa tyy1-tyy117 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_prop tefa tx* tyy* tss* [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho

/* Column 3 */
regress lpc_murd efamu xx*  ryy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_murd efamu ryy* ss*  \ new tpc_murd tefa tyy1-tyy117 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_murd efamu ryy* ss* xx* \ var tpc_murd tefa tyy1-tyy117 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_murd tefa tx* tyy* tss*  [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho

drop ryy* 


/* Row 13: Control for fertility 20 years earlier */

sort statenum year
generate xxfert=fertil[_n-19] if statenum==statenum[_n-19]
generate txfert=xxfert

/* Column 1 */
regress lpc_viol efav xx*  yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_viol efav yy* ss*  \ new tpc_viol tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_viol efav yy* ss* xx* \ var tpc_viol tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_viol tefa tx* tyy* tss* [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho

/* Column 2 */
regress lpc_prop efap xx*  yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_prop efap yy* ss*  \ new tpc_prop tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_prop efap yy* ss* xx* \ var tpc_prop tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_prop tefa tx* tyy* tss* [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho

/* Column 3 */
regress lpc_murd efamu xx*  yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var lpc_murd efamu yy* ss*  \ new tpc_murd tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var lpc_murd efamu yy* ss* xx* \ var tpc_murd tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_murd tefa tx* tyy* tss*  [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho

drop xxfert  txfert


/* Row 14: Long difference estimates using only 85 and 97 data */

/* Column 1 */
regress lpc_viol efav xx*  yy* ss* if year==85|year==97 [aw=popul], robust 

/* Column 2 */
regress lpc_prop efap xx*  yy* ss* if year==85|year==97   [aw=popul], robust 

/* Column 3 */
regress lpc_murd efamu xx*  yy* ss* if year==85|year==97  [aw=popul], robust 

/* **************************************************** */
/* Table 6 */

**arrest rates per capita, by age
generate l_ymurd=ln(mur_u25/a024)
generate l_yviol=ln(vio_u25/a024)
generate l_yprop=ln(pro_u25/a024)

generate l_omurd=ln(mur_o25/a25p)
generate l_oviol=ln(vio_o25/a25p)
generate l_oprop=ln(pro_o25/a25p)

generate dif_murd=l_ymurd-l_omurd
generate dif_viol=l_yviol-l_oviol
generate dif_prop=l_yprop-l_oprop

/* Under Age 25, Without Full Covariates */
**1. Violent Crime
regress l_yviol efav  yy* ss*  [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var l_yviol efav yy* ss*  \ new t_yviol tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var l_yviol efav yy* ss* \ var t_yviol tefa tyy1-tyy33 tss1-tss51: replace Y=X*(1-rho^2)^.5 if year==85
regress t_yviol tefa  tyy* tss*  [aw=popul], robust
drop t_y* tefa* tyy* tss*  resid* rho
**2. Property Crime
regress l_yprop efap  yy* ss*   [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var l_yprop efap yy* ss*  \ new t_yprop tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var l_yprop efap yy* ss* \ var t_yprop tefa tyy1-tyy33 tss1-tss51: replace Y=X*(1-rho^2)^.5 if year==85
regress t_yprop tefa  tyy* tss*  [aw=popul], robust
drop t_y* tefa* tyy* tss*  resid* rho
**3. Murder
regress l_ymurd efamu  yy* ss*  [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var l_ymurd efamu yy* ss*  \ new t_ymurd tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var l_ymurd efamu yy* ss* \ var t_ymurd tefa tyy1-tyy33 tss1-tss51: replace Y=X*(1-rho^2)^.5 if year==85
regress t_ymurd tefa  tyy* tss*  [aw=popul], robust
drop t_y* tefa* tyy* tss*  resid* rho

/* Under Age 25, With Full Covariates*/
**1. Violent Crime
regress l_yviol efav xx*  yy* ss*  [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var l_yviol efav yy* ss*  \ new t_yviol tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var l_yviol efav yy* ss* xx* \ var t_yviol tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress t_yviol tefa tx* tyy* tss*  [aw=popul], robust
drop t_y* tefa* tyy* tss*  resid* rho
**2. Property Crime
regress l_yprop efap xx*  yy* ss*   [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var l_yprop efap yy* ss*  \ new t_yprop tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var l_yprop efap yy* ss* xx* \ var t_yprop tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress t_yprop tefa tx* tyy* tss*  [aw=popul], robust
drop t_y* tefa* tyy* tss*  resid* rho
**3. Murder
regress l_ymurd efamu xx*  yy* ss*  [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var l_ymurd efamu yy* ss*  \ new t_ymurd tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var l_ymurd efamu yy* ss* xx* \ var t_ymurd tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress t_ymurd tefa tx* tyy* tss*  [aw=popul], robust
drop t_y* tefa* tyy* tss*  resid* rho

/* Age 25+, Without Full Covariates */
**1. Violent Crime
regress l_oviol efav  yy* ss*  [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var l_oviol efav yy* ss*  \ new t_oviol tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var l_oviol efav yy* ss* \ var t_oviol tefa tyy1-tyy33 tss1-tss51: replace Y=X*(1-rho^2)^.5 if year==85
regress t_oviol tefa  tyy* tss*  [aw=popul], robust
drop t_o* tefa* tyy* tss*  resid* rho
**2. Property Crime
regress l_oprop efap  yy* ss*   [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var l_oprop efap yy* ss*  \ new t_oprop tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var l_oprop efap yy* ss* \ var t_oprop tefa tyy1-tyy33 tss1-tss51: replace Y=X*(1-rho^2)^.5 if year==85
regress t_oprop tefa  tyy* tss*  [aw=popul], robust
drop t_o* tefa* tyy* tss*  resid* rho
**3. Murder
regress l_omurd efamu  yy* ss*  [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var l_omurd efamu yy* ss*  \ new t_omurd tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var l_omurd efamu yy* ss* \ var t_omurd tefa tyy1-tyy33 tss1-tss51: replace Y=X*(1-rho^2)^.5 if year==85
regress t_omurd tefa  tyy* tss*  [aw=popul], robust
drop t_o* tefa* tyy* tss*  resid* rho

/* Age 25+, With Full Covariates*/
**1. Violent Crime
regress l_oviol efav xx*  yy* ss*  [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var l_oviol efav yy* ss*  \ new t_oviol tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var l_oviol efav yy* ss* xx* \ var t_oviol tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress t_oviol tefa tx* tyy* tss*  [aw=popul], robust
drop t_o* tefa* tyy* tss*  resid* rho
**2. Property Crime
regress l_oprop efap xx*  yy* ss*   [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var l_oprop efap yy* ss*  \ new t_oprop tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var l_oprop efap yy* ss* xx* \ var t_oprop tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress t_oprop tefa tx* tyy* tss*  [aw=popul], robust
drop t_o* tefa* tyy* tss*  resid* rho
**3. Murder
regress l_omurd efamu xx*  yy* ss*  [aw=popul], robust 
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var l_omurd efamu yy* ss*  \ new t_omurd tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var l_omurd efamu yy* ss* xx* \ var t_omurd tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress t_omurd tefa tx* tyy* tss*  [aw=popul], robust
drop t_o* tefa* tyy* tss*  resid* rho

/* Under Age 25 minus Age 25+, Without Covariates */
**1. Violent Crime
regress dif_viol efav  yy* ss*  [aw=popul], robust cluster(statenum)
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var dif_viol efav yy* ss*  \ new tif_viol tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var dif_viol efav yy* ss* \ var tif_viol tefa tyy1-tyy33 tss1-tss51: replace Y=X*(1-rho^2)^.5 if year==85
regress tif_viol tefa  tyy* tss*  [aw=popul], robust
drop tif* tefa* tyy* tss*  resid* rho
**2. Property Crime
regress dif_prop efap  yy* ss*   [aw=popul], robust cluster(statenum)
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var dif_prop efap yy* ss*  \ new tif_prop tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var dif_prop efap yy* ss* \ var tif_prop tefa tyy1-tyy33 tss1-tss51: replace Y=X*(1-rho^2)^.5 if year==85
regress tif_prop tefa  tyy* tss*  [aw=popul], robust
drop tif* tefa* tyy* tss*  resid* rho
**3. Murder
regress dif_murd efamu  yy* ss*  [aw=popul], robust cluster(statenum)
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var dif_murd efamu yy* ss*  \ new tif_murd tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var dif_murd efamu yy* ss* \ var tif_murd tefa tyy1-tyy33 tss1-tss51: replace Y=X*(1-rho^2)^.5 if year==85
regress tif_murd tefa  tyy* tss*  [aw=popul], robust
drop tif* tefa* tyy* tss*  resid* rho

/* Under Age 25 minus Age 25+, With Covariates */
**1. Violent Crime
regress dif_viol efav xx*  yy* ss*  [aw=popul], robust cluster(statenum)
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var dif_viol efav yy* ss*  \ new tif_viol tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var dif_viol efav yy* ss* xx* \ var tif_viol tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tif_viol tefa tx* tyy* tss*  [aw=popul], robust
drop tif* tefa* tyy* tss*  resid* rho
**2. Property Crime
regress dif_prop efap xx*  yy* ss*   [aw=popul], robust cluster(statenum)
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var dif_prop efap yy* ss*  \ new tif_prop tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var dif_prop efap yy* ss* xx* \ var tif_prop tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tif_prop tefa tx* tyy* tss*  [aw=popul], robust
drop tif* tefa* tyy* tss*  resid* rho
**3. Murder
regress dif_murd efamu xx*  yy* ss*  [aw=popul], robust cluster(statenum)
predict resid, resid
sort statenum year
generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
generate resid1sq=(resid-resid1)^2
generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
generate rho=1-(residnum/residden)/2
sort statenum year
for var dif_murd efamu yy* ss*  \ new tif_murd tefa tyy1-tyy33 tss1-tss51 : generate Y=X-rho*X[_n-1]
for var xx* \ var tx*: replace Y=X-rho*X[_n-1]
for var dif_murd efamu yy* ss* xx* \ var tif_murd tefa tyy1-tyy33 tss1-tss51 tx*: replace Y=X*(1-rho^2)^.5 if year==85
regress tif_murd tefa tx* tyy* tss*  [aw=popul], robust
drop tif* tefa* tyy* tss*  resid* rho


/* ************************************************ */
/* Table 7 */

keep statenum year mur* vio* pro* abort* xx* popul 
expand 10
sort statenum year
generate age=15
replace age=age[_n-1]+1 if statenum==statenum[_n-1]&year==year[_n-1]

summ
sort age statenum year
generate abort2=0

replace abort2=abort[_n-16] if age==15&statenum==statenum[_n-16]&age[_n-16]==age
replace abort2=abort[_n-17] if age==16&statenum==statenum[_n-17]&age[_n-17]==age
replace abort2=abort[_n-18] if age==17&statenum==statenum[_n-18]&age[_n-18]==age
replace abort2=abort[_n-19] if age==18&statenum==statenum[_n-19]&age[_n-19]==age
replace abort2=abort[_n-20] if age==19&statenum==statenum[_n-20]&age[_n-20]==age
replace abort2=abort[_n-21] if age==20&statenum==statenum[_n-21]&age[_n-21]==age
replace abort2=abort[_n-22] if age==21&statenum==statenum[_n-22]&age[_n-22]==age
replace abort2=abort[_n-23] if age==22&statenum==statenum[_n-23]&age[_n-23]==age
replace abort2=abort[_n-24] if age==23&statenum==statenum[_n-24]&age[_n-24]==age
replace abort2=abort[_n-25] if age==24&statenum==statenum[_n-25]&age[_n-25]==age

summ abort2
summ abort2 if year==90&age==15
summ abort2 if year==90&age==22
replace abort2=0 if abort2==.

generate violarr=.
replace violarr=vioarr15 if age==15
replace violarr=vioarr16 if age==16
replace violarr=vioarr17 if age==17
replace violarr=vioarr18 if age==18
replace violarr=vioarr19 if age==19
replace violarr=vioarr20 if age==20
replace violarr=vioarr21 if age==21
replace violarr=vioarr22 if age==22
replace violarr=vioarr23 if age==23
replace violarr=vioarr24 if age==24

generate proparr=.
replace proparr=proarr15 if age==15
replace proparr=proarr16 if age==16
replace proparr=proarr17 if age==17
replace proparr=proarr18 if age==18
replace proparr=proarr19 if age==19
replace proparr=proarr20 if age==20
replace proparr=proarr21 if age==21
replace proparr=proarr22 if age==22
replace proparr=proarr23 if age==23
replace proparr=proarr24 if age==24

generate murdarr=.
replace murdarr=murarr15 if age==15
replace murdarr=murarr16 if age==16
replace murdarr=murarr17 if age==17
replace murdarr=murarr18 if age==18
replace murdarr=murarr19 if age==19
replace murdarr=murarr20 if age==20
replace murdarr=murarr21 if age==21
replace murdarr=murarr22 if age==22
replace murdarr=murarr23 if age==23
replace murdarr=murarr24 if age==24

generate l_viol=ln(violarr)
generate l_prop=ln(proparr)
generate l_murd=ln(murdarr)

keep if year>84 & year<97

tab year, gen(yy) nof
tab statenum, gen(ss) nof
tab age, gen(aa) nof

generate yob=year-age
generate yobxsta=statenum*1000+yob

**generate statexage interactions
generate staxage=statenum*1000+age

**generate year*age interactions
generate yearxage=year*1000+age
tab yearxage, gen (ya) nof

**dividing by 100 to make consistent with other regressions

replace abort2=abort2/100

generate abor15=abort2*(age==15)
generate abor16=abort2*(age==16)
generate abor17=abort2*(age==17)
generate abor18=abort2*(age==18)
generate abor19=abort2*(age==19)
generate abor20=abort2*(age==20)
generate abor21=abort2*(age==21)
generate abor22=abort2*(age==22)
generate abor23=abort2*(age==23)
generate abor24=abort2*(age==24)

/* Column 1 */
regress l_viol abort2 ya* ss*  [aw=popul], robust cluster(yobxsta)

/* Column 2 */
regress l_viol abor15-abor24 ya* ss*  [aw=popul], robust cluster(yobxsta)

/* Column 3 */
areg l_viol abort2 ya*   [aw=popul], abs(staxage) robust cluster(yobxsta)

/* Column 4 */
areg l_viol abor15-abor24 ya*   [aw=popul], abs(staxage) robust cluster(yobxsta)

/* Column 5 */
regress l_prop abort2 ya* ss*  [aw=popul], robust cluster(yobxsta) 

/* Column 6*/
regress l_prop abor15-abor24 ya* ss*  [aw=popul], robust cluster(yobxsta) 

/* Column 7 */
areg l_prop abort2 ya*   [aw=popul], abs(staxage) robust cluster(yobxsta) 

/* Column 8 */
areg l_prop abor15-abor24 ya*   [aw=popul], abs(staxage) robust cluster(yobxsta) 



log close
