/* ********************************************************************************* */
/* ******************* Violent Crime   ********************************************* */
/* ********************************************************************************* */

**************************************************************
* 1.) DONOHUE-LEVITT METHOD (weighted by POPUL, rhotype=DW, twostep)
*     ** Reported in D-L 2001 **

clear 
use ../../../DLdata/dlabo.dta
sort statenum year
tsset statenum year
tab year, gen(yy) nof
tab statenum, gen(ss) nof

qui regress lpc_viol efaviol yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
qui generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
qui generate resid1sq=(resid-resid1)^2
qui generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
qui generate rho=1-(residnum/residden)/2
summ rho
sort statenum year
for var lpc_viol efaviol yy* ss*  \ new tpc_viol tefa tyy1-tyy33 tss1-tss51 : qui generate Y=X-rho*X[_n-1]
for var lpc_viol efaviol yy* ss*  \ var tpc_viol tefa tyy1-tyy33 tss1-tss51 : replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_viol tefa tyy* tss* [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho








***********************************************************
* 2.) DONOHUE-LEVITT METHOD (unweighted, rhotype=DW, twostep) 

qui regress lpc_viol efaviol yy* ss*, robust 
predict resid, resid
sort statenum year
qui generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
qui generate resid1sq=(resid-resid1)^2
qui generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
qui generate rho=1-(residnum/residden)/2
summ rho
sort statenum year
for var lpc_viol efaviol yy* ss*  \ new tpc_viol tefa tyy1-tyy33 tss1-tss51 : qui generate Y=X-rho*X[_n-1]
for var lpc_viol efaviol yy* ss*  \ var tpc_viol tefa tyy1-tyy33 tss1-tss51 : replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_viol tefa tyy* tss*, robust
drop tpc* tefa* tyy* tss* resid* rho







***********************************************************
* 3.) STATA PRAIS-WINSTEN (unweighted, rhotype=DW, twostep) -- should match #2
prais lpc_viol efaviol yy* ss*, robust rhotype(dw) twostep






***********************************************************
* 4.) STATA PRAIS-WINSTEN w/rhotype=REGRESS (unweighted, rhotype=regress, twostep)
prais lpc_viol efaviol yy* ss*, robust rhotype(regress) twostep







**********************************************************
* 5.) DO Prais-Winsten the D-L way (by hand) (rhotype=regress, unweighted, twostep) -- should match #4)

qui regress lpc_viol efaviol yy* ss*, robust 
predict resid, resid
sort statenum year
qui generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
qui regress resid resid1 if year > 85
gen myrho = _b[resid1]
for var lpc_viol efaviol yy* ss*  \ new tpc_viol tefa tyy1-tyy33 tss1-tss51 : qui generate Y=X-myrho*X[_n-1]
for var lpc_viol efaviol yy* ss*  \ var tpc_viol tefa tyy1-tyy33 tss1-tss51 : replace Y=X*(1-myrho^2)^.5 if year==85
regress tpc_viol tefa tyy* tss*, robust
drop tpc* tefa* tyy* tss* resid* myrho






***********************************************************
* 6.) STATA PRAIS-WINSTEN with XI (unweighted, rhotype=regress, twostep) 
*      -- should match #4 & #5

use ../../../data/dlab_fg06, clear
replace year = year + 1900
keep if year >= 1985 & year <= 2003
egen popwt = mean(censpop), by(fips)

keep if year >= 1985 & year <= 1997

sort fips year
tsset fips year

xi: prais lpc_viol efaviol i.year i.fips, robust rhotype(regress) twostep







***********************************************************
* 7.) STATA PRAIS-WINSTEN with XI (weighted by constant POPWT, rhotype=regress, twostep) 

xi: prais lpc_viol efaviol i.year i.fips [aw=popwt], weights robust rhotype(regress) twostep







***********************************************************
* 8.) STATA PRAIS-WINSTEN with XI (weighted by constant POPWT, rhotype=regress, iterated) 

xi: prais lpc_viol efaviol i.year i.fips [aw=popwt], weights robust rhotype(regress) 







***********************************************************
* 9 .) STATA PRAIS-WINSTEN with XI and NEWLPCVIOL (weighted by constant POPWT, rhotype=regress) 
*     ** REPORTED IN FIRST COLUMN TABLE II OF F-G (2006 -- August 14 version) **

xi: prais newlpc_viol efaviol i.year i.fips [aw=popwt], weights robust rhotype(regress)








/* ********************************************************************************* */
/* ******************* Property Crime  ********************************************* */
/* ********************************************************************************* */


**************************************************************
* 1.) DONOHUE-LEVITT METHOD (weighted by POPUL, rhotype=DW, twostep)
*     ** Reported in D-L 2001 **

clear 
use ../../../DLdata/dlabo.dta
sort statenum year
tsset statenum year
tab year, gen(yy) nof
tab statenum, gen(ss) nof

qui regress lpc_prop efaprop yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
qui generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
qui generate resid1sq=(resid-resid1)^2
qui generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
qui generate rho=1-(residnum/residden)/2
summ rho
sort statenum year
for var lpc_prop efaprop yy* ss*  \ new tpc_prop tefa tyy1-tyy33 tss1-tss51 : qui generate Y=X-rho*X[_n-1]
for var lpc_prop efaprop yy* ss*  \ var tpc_prop tefa tyy1-tyy33 tss1-tss51 : replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_prop tefa tyy* tss* [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho








***********************************************************
* 2.) DONOHUE-LEVITT METHOD (unweighted, rhotype=DW, twostep) 

qui regress lpc_prop efaprop yy* ss*, robust 
predict resid, resid
sort statenum year
qui generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
qui generate resid1sq=(resid-resid1)^2
qui generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
qui generate rho=1-(residnum/residden)/2
summ rho
sort statenum year
for var lpc_prop efaprop yy* ss*  \ new tpc_prop tefa tyy1-tyy33 tss1-tss51 : qui generate Y=X-rho*X[_n-1]
for var lpc_prop efaprop yy* ss*  \ var tpc_prop tefa tyy1-tyy33 tss1-tss51 : replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_prop tefa tyy* tss*, robust
drop tpc* tefa* tyy* tss* resid* rho







***********************************************************
* 3.) STATA PRAIS-WINSTEN (unweighted, rhotype=DW, twostep) -- should match #2
prais lpc_prop efaprop yy* ss*, robust rhotype(dw) twostep






***********************************************************
* 4.) STATA PRAIS-WINSTEN w/rhotype=REGRESS (unweighted, rhotype=regress, twostep)
prais lpc_prop efaprop yy* ss*, robust rhotype(regress) twostep







**********************************************************
* 5.) DO Prais-Winsten the D-L way (by hand) (rhotype=regress, unweighted, twostep) -- should match #4)

qui regress lpc_prop efaprop yy* ss*, robust 
predict resid, resid
sort statenum year
qui generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
qui regress resid resid1 if year > 85
gen myrho = _b[resid1]
for var lpc_prop efaprop yy* ss*  \ new tpc_prop tefa tyy1-tyy33 tss1-tss51 : qui generate Y=X-myrho*X[_n-1]
for var lpc_prop efaprop yy* ss*  \ var tpc_prop tefa tyy1-tyy33 tss1-tss51 : replace Y=X*(1-myrho^2)^.5 if year==85
regress tpc_prop tefa tyy* tss*, robust
drop tpc* tefa* tyy* tss* resid* myrho






***********************************************************
* 6.) STATA PRAIS-WINSTEN with XI (unweighted, rhotype=regress, twostep) 
*      -- should match #4 & #5

use ../../../data/dlab_fg06, clear
replace year = year + 1900
keep if year >= 1985 & year <= 2003
egen popwt = mean(censpop), by(fips)

keep if year >= 1985 & year <= 1997

sort fips year
tsset fips year

xi: prais lpc_prop efaprop i.year i.fips, robust rhotype(regress) twostep







***********************************************************
* 7.) STATA PRAIS-WINSTEN with XI (weighted by constant POPWT, rhotype=regress, twostep) 

xi: prais lpc_prop efaprop i.year i.fips [aw=popwt], weights robust rhotype(regress) twostep







***********************************************************
* 8.) STATA PRAIS-WINSTEN with XI (weighted by constant POPWT, rhotype=regress, iterated) 

xi: prais lpc_prop efaprop i.year i.fips [aw=popwt], weights robust rhotype(regress) 







***********************************************************
* 9 .) STATA PRAIS-WINSTEN with XI and NEWLPCPROP (weighted by constant POPWT, rhotype=regress) 
*     ** REPORTED IN FIRST COLUMN TABLE II OF F-G (2006 -- August 14 version) **

xi: prais newlpc_prop efaprop i.year i.fips [aw=popwt], weights robust rhotype(regress)









/* ******************************************************************************* */
/* ****************** Murder ***************************************************** */
/* ******************************************************************************* */


**************************************************************
* 1.) DONOHUE-LEVITT METHOD (weighted by POPUL, rhotype=DW, twostep)
*     ** Reported in D-L 2001 **

clear 
use ../../../DLdata/dlabo.dta
sort statenum year
tsset statenum year
tab year, gen(yy) nof
tab statenum, gen(ss) nof

qui regress lpc_murd efamurd yy* ss* [aw=popul], robust 
predict resid, resid
sort statenum year
qui generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
qui generate resid1sq=(resid-resid1)^2
qui generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
qui generate rho=1-(residnum/residden)/2
summ rho
sort statenum year
for var lpc_murd efamurd yy* ss*  \ new tpc_murd tefa tyy1-tyy33 tss1-tss51 : qui generate Y=X-rho*X[_n-1]
for var lpc_murd efamurd yy* ss*  \ var tpc_murd tefa tyy1-tyy33 tss1-tss51 : replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_murd tefa tyy* tss* [aw=popul], robust
drop tpc* tefa* tyy* tss* resid* rho








***********************************************************
* 2.) DONOHUE-LEVITT METHOD (unweighted, rhotype=DW, twostep) 

qui regress lpc_murd efamurd yy* ss*, robust 
predict resid, resid
sort statenum year
qui generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
qui generate resid1sq=(resid-resid1)^2
qui generate residsq=resid^2 if year>84&year<98
egen residnum=sum(resid1sq) if year>84&year<98
egen residden=sum(residsq) if year>84&year<98
qui generate rho=1-(residnum/residden)/2
summ rho
sort statenum year
for var lpc_murd efamurd yy* ss*  \ new tpc_murd tefa tyy1-tyy33 tss1-tss51 : qui generate Y=X-rho*X[_n-1]
for var lpc_murd efamurd yy* ss*  \ var tpc_murd tefa tyy1-tyy33 tss1-tss51 : replace Y=X*(1-rho^2)^.5 if year==85
regress tpc_murd tefa tyy* tss*, robust
drop tpc* tefa* tyy* tss* resid* rho







***********************************************************
* 3.) STATA PRAIS-WINSTEN (unweighted, rhotype=DW, twostep) -- should match #2
prais lpc_murd efamurd yy* ss*, robust rhotype(dw) twostep






***********************************************************
* 4.) STATA PRAIS-WINSTEN w/rhotype=REGRESS (unweighted, rhotype=regress, twostep)
prais lpc_murd efamurd yy* ss*, robust rhotype(regress) twostep







**********************************************************
* 5.) DO Prais-Winsten the D-L way (by hand) (rhotype=regress, unweighted, twostep) -- should match #4)

qui regress lpc_murd efamurd yy* ss*, robust 
predict resid, resid
sort statenum year
qui generate resid1=resid[_n-1] if statenum==statenum[_n-1]&year>84&year<98
qui regress resid resid1 if year > 85
gen myrho = _b[resid1]
for var lpc_murd efamurd yy* ss*  \ new tpc_murd tefa tyy1-tyy33 tss1-tss51 : qui generate Y=X-myrho*X[_n-1]
for var lpc_murd efamurd yy* ss*  \ var tpc_murd tefa tyy1-tyy33 tss1-tss51 : replace Y=X*(1-myrho^2)^.5 if year==85
regress tpc_murd tefa tyy* tss*, robust
drop tpc* tefa* tyy* tss* resid* myrho






***********************************************************
* 6.) STATA PRAIS-WINSTEN with XI (unweighted, rhotype=regress, twostep) 
*      -- should match #4 & #5

use ../../../data/dlab_fg06, clear
replace year = year + 1900
keep if year >= 1985 & year <= 2003
egen popwt = mean(censpop), by(fips)

keep if year >= 1985 & year <= 1997

sort fips year
tsset fips year

xi: prais lpc_murd efamurd i.year i.fips, robust rhotype(regress) twostep







***********************************************************
* 7.) STATA PRAIS-WINSTEN with XI (weighted by constant POPWT, rhotype=regress, twostep) 

xi: prais lpc_murd efamurd i.year i.fips [aw=popwt], weights robust rhotype(regress) twostep







***********************************************************
* 8.) STATA PRAIS-WINSTEN with XI (weighted by constant POPWT, rhotype=regress, iterated) 

xi: prais lpc_murd efamurd i.year i.fips [aw=popwt], weights robust rhotype(regress) 







***********************************************************
* 9 .) STATA PRAIS-WINSTEN with XI and NEWLPCMURD (weighted by constant POPWT, rhotype=regress) 
*     ** REPORTED IN FIRST COLUMN TABLE II OF F-G (2006 -- August 14 version) **

xi: prais newlpc_murd efamurd i.year i.fips [aw=popwt], weights robust rhotype(regress)








exit, clear
