/* ****************************************** */
/* STYRAGE.DO                                 */
/* You must use STATA-SE to run this program  */
/* ****************************************** */

drop _all 
set more 1 
set memory 1g
set matsize 8000 

clear 
use "../../DLdata/dlabo.dta"

/* ************************************************ */
/* Table 7 */

keep statenum year mur* vio* pro* abort* xx* popul 

expand 10
sort statenum year
generate age=15
replace age=age[_n-1]+1 if statenum==statenum[_n-1]&year==year[_n-1]

summ
sort age statenum year
generate abort2=0

replace abort2=abort[_n-16] if age==15&statenum==statenum[_n-16]&age[_n-16]==age
replace abort2=abort[_n-17] if age==16&statenum==statenum[_n-17]&age[_n-17]==age
replace abort2=abort[_n-18] if age==17&statenum==statenum[_n-18]&age[_n-18]==age
replace abort2=abort[_n-19] if age==18&statenum==statenum[_n-19]&age[_n-19]==age
replace abort2=abort[_n-20] if age==19&statenum==statenum[_n-20]&age[_n-20]==age
replace abort2=abort[_n-21] if age==20&statenum==statenum[_n-21]&age[_n-21]==age
replace abort2=abort[_n-22] if age==21&statenum==statenum[_n-22]&age[_n-22]==age
replace abort2=abort[_n-23] if age==22&statenum==statenum[_n-23]&age[_n-23]==age
replace abort2=abort[_n-24] if age==23&statenum==statenum[_n-24]&age[_n-24]==age
replace abort2=abort[_n-25] if age==24&statenum==statenum[_n-25]&age[_n-25]==age

summ abort2
summ abort2 if year==90&age==15
summ abort2 if year==90&age==22
replace abort2=0 if abort2==.

generate violarr=.
replace violarr=vioarr15 if age==15
replace violarr=vioarr16 if age==16
replace violarr=vioarr17 if age==17
replace violarr=vioarr18 if age==18
replace violarr=vioarr19 if age==19
replace violarr=vioarr20 if age==20
replace violarr=vioarr21 if age==21
replace violarr=vioarr22 if age==22
replace violarr=vioarr23 if age==23
replace violarr=vioarr24 if age==24

generate proparr=.
replace proparr=proarr15 if age==15
replace proparr=proarr16 if age==16
replace proparr=proarr17 if age==17
replace proparr=proarr18 if age==18
replace proparr=proarr19 if age==19
replace proparr=proarr20 if age==20
replace proparr=proarr21 if age==21
replace proparr=proarr22 if age==22
replace proparr=proarr23 if age==23
replace proparr=proarr24 if age==24

generate murdarr=.
replace murdarr=murarr15 if age==15
replace murdarr=murarr16 if age==16
replace murdarr=murarr17 if age==17
replace murdarr=murarr18 if age==18
replace murdarr=murarr19 if age==19
replace murdarr=murarr20 if age==20
replace murdarr=murarr21 if age==21
replace murdarr=murarr22 if age==22
replace murdarr=murarr23 if age==23
replace murdarr=murarr24 if age==24

generate l_viol=ln(violarr)
generate l_prop=ln(proparr)
generate l_murd=ln(murdarr)

* keep if year > 84 & year < 99
keep if year > 84 & year < 97

* tab statenum, gen(ss) nof

generate yob=year-age
generate yobxsta=statenum*1000+yob

**dividing by 100 to make consistent with other regressions

replace abort2=abort2/100

generate abor15=abort2*(age==15)
generate abor16=abort2*(age==16)
generate abor17=abort2*(age==17)
generate abor18=abort2*(age==18)
generate abor19=abort2*(age==19)
generate abor20=abort2*(age==20)
generate abor21=abort2*(age==21)
generate abor22=abort2*(age==22)
generate abor23=abort2*(age==23)
generate abor24=abort2*(age==24)

/* **************************** */
/* Merge in the population data */
/* and create per-capita arrest */
/* variables                    */

replace year = year + 1900
sort statenum year age
save fg1temp, replace
clear 

infile fips year age seerpop censuspop using ../../data/popdata/combined.dat

/* Have to add a STATENUM variable to poplation data in */
/* order to match to the DLABO dataset                  */
sort  fips 
merge fips using ../../DLdata/statenum2fips
tab _merge
drop _merge
drop fips

sort  statenum year age
merge statenum year age using fg1temp

keep if year >= 1985 & year <= 1996
keep if  age >= 15 & age <= 24

tab _merge
drop _merge

* Generate log of population variables;
gen lncensus = ln(censuspop)
gen   lnseer = ln(seerpop)

* Generate log of per capita variables 
gen lpc_viol_census = ln(violarr/censuspop)
gen lpc_viol_seer   = ln(violarr/seerpop)
gen lpc_prop_census = ln(proparr/censuspop)
gen lpc_prop_seer   = ln(proparr/seerpop)

/* End of merging and creating   */
/* population data and variables */
/* ***************************** */

*************************************************
* Property Crime                                   

* DL's specification 
xi: reg l_prop abort2            i.year*i.age i.statenum*i.age                   [aw=popul], robust cluster(yobxsta)
xi: reg l_prop abort2            i.year*i.age i.statenum*i.age                   [aw=popul], robust cluster(statenum)

* Add state-year controls
xi: reg l_prop abort2            i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(yobxsta)
xi: reg l_prop abort2            i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(statenum)

* Add log of population as explanatory variable 
xi: reg l_prop abort2 lncensus   i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(yobxsta)
xi: reg l_prop abort2 lncensus   i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(statenum)
xi: reg l_prop abort2 lnseer     i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(yobxsta)
xi: reg l_prop abort2 lnseer     i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(statenum)

* Define arrests as arrests per capita 
xi: reg lpc_prop_census abort2   i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(yobxsta) 
xi: reg lpc_prop_census abort2   i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(statenum)
xi: reg lpc_prop_seer abort2     i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(yobxsta) 
xi: reg lpc_prop_seer abort2     i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(statenum)

* Arrests per capita WITHOUT state-year effects 
xi: reg lpc_prop_census abort2   i.year*i.age i.statenum*i.age                   [aw=popul], robust cluster(yobxsta) 
xi: reg lpc_prop_census abort2   i.year*i.age i.statenum*i.age                   [aw=popul], robust cluster(statenum)
xi: reg lpc_prop_seer abort2     i.year*i.age i.statenum*i.age                   [aw=popul], robust cluster(yobxsta) 
xi: reg lpc_prop_seer abort2     i.year*i.age i.statenum*i.age                   [aw=popul], robust cluster(statenum)


************************************************* 
* Violent Crime                                   

* DL's specification 
xi: reg l_viol abort2            i.year*i.age i.statenum*i.age                   [aw=popul], robust cluster(yobxsta)
xi: reg l_viol abort2            i.year*i.age i.statenum*i.age                   [aw=popul], robust cluster(statenum)

* Add state-year controls
xi: reg l_viol abort2            i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(yobxsta)
xi: reg l_viol abort2            i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(statenum)

* Add log of population as explanatory variable 
xi: reg l_viol abort2 lncensus   i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(yobxsta)
xi: reg l_viol abort2 lncensus   i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(statenum)
xi: reg l_viol abort2 lnseer     i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(yobxsta)
xi: reg l_viol abort2 lnseer     i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(statenum)

* Define arrests as arrests per capita 
xi: reg lpc_viol_census abort2   i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(yobxsta) 
xi: reg lpc_viol_census abort2   i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(statenum)
xi: reg lpc_viol_seer abort2     i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(yobxsta) 
xi: reg lpc_viol_seer abort2     i.year*i.age i.statenum*i.age i.statenum*i.year [aw=popul], robust cluster(statenum)

* Arrests per capita WITHOUT state-year effects 
xi: reg lpc_viol_census abort2   i.year*i.age i.statenum*i.age                   [aw=popul], robust cluster(yobxsta) 
xi: reg lpc_viol_census abort2   i.year*i.age i.statenum*i.age                   [aw=popul], robust cluster(statenum)
xi: reg lpc_viol_seer abort2     i.year*i.age i.statenum*i.age                   [aw=popul], robust cluster(yobxsta) 
xi: reg lpc_viol_seer abort2     i.year*i.age i.statenum*i.age                   [aw=popul], robust cluster(statenum)


clear
erase fg1temp.dta

*
* Now use adjusted data from DL (2006) 
* ;

#delimit ;
use ../../data/adata;
summ;

keep if year >= 1985 & year <= 1998;

gen l_prop_pc_s = ln(proparr/seerpop);
gen l_viol_pc_s = ln(violarr/seerpop);

list fips year age censuspop seerpop if fips == 1 & year == 1998;

/* Property Crime ************************************ */

xi: reg l_prop_pc_s hist_abt                 i.fips*i.year i.fips*i.age i.age*i.year [aw=popul] , cluster(yobstate);
xi: reg l_prop_pc_s hist_abt                 i.fips*i.year i.fips*i.age i.age*i.year [aw=popul] , cluster(fips);
											       
/* Violent Crime ************************************* */				       
											       
xi: reg l_viol_pc_s hist_abt                 i.fips*i.year i.fips*i.age i.age*i.year [aw=popul] , cluster(yobstate);
xi: reg l_viol_pc_s hist_abt                 i.fips*i.year i.fips*i.age i.age*i.year [aw=popul] , cluster(fips);


exit, clear;
